; division.inc
; 15.06.2021
; 
;
;========================================================================================
;=== Macro fuer Division ================================================================
;========================================================================================
;
;=================================================================================
;=== div unsigned ================================================================
;=================================================================================
; div_8x8		@0 Ergebnis, @1 Rest, @2 Divident, @3 Divisor
; 				Division 	8/8 -> 8 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...255, 
;				Divisor  1...255
; 				Ergebnis 0...255, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				94/78/4 Cycles 
;				(Divident=255 Divisor=1/Divident=0 Divisor=1/Divisor=0),  
; 				34 Bytes
;
;
; div_16x8		@0,1 Ergebnis (@1 MSB), @2 Rest
; 				@3,4 Divident (@4 MSB), @5 Divisor
; 				@6 Rest-Erweiterung, @7 Null-Register
; 				Division 	16/8 -> 16 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...65535, 
;				Divisor  1...255
; 				Ergebnis 0...65535, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				265/217/4 Cycles 
;				(Divident=65535 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				50 Bytes
;
;
; div_24x8		@0,1,2 Ergebnis (@2 MSB), @3 Rest
; 				@4,5,6 Divident (@6 MSB), @7 Divisor
; 				@8 Rest-Erweiterung, @9 Null-Register
; 				Division 	24/8 -> 24 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...16777215, 
;				Divisor  1...255
; 				Ergebnis 0...16777215, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				442/370/4 Cycles 
;				(Divident=16777215 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				56 Bytes
;
;
; div_32x8		@0,1,2,3 Ergebnis (@3 MSB), @4 Rest
; 				@5,6,7,8 Divident (@8 MSB), @9 Divisor
; 				@10 Rest-Erweiterung, @11 Null-Register
; 				Division 	32/8 -> 32 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...4294967295, 
;				Divisor  1...255
; 				Ergebnis 0...4294967295, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				651/555/4 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				62 Bytes
;
;
; div_40x8		@0,1,2,3,4 Ergebnis (@4 MSB), @5 Rest
; 				@6,7,8,9,10 Divident (@10 MSB), @11 Divisor
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	40/8 -> 40 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...1099511627775, 
;				Divisor  1...255
; 				Ergebnis 0...1099511627775, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				892/772/4 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				68 Bytes
;
;
; div_48x8		@0,1,2,3,4,5 Ergebnis (@5 MSB), @6 Rest
; 				@7,8,9,10,11,12 Divident (@12 MSB), @13 Divisor
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	48/8 -> 48 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...281474976710655, 
;				Divisor  1...255
; 				Ergebnis 0...281474976710655, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				1165/1021/4 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				74 Bytes
;
;
; div_56x8		@0,1,2,3,4,5,6 Ergebnis (@6 MSB), @7 Rest
; 				@8,9,10,11,12,13,14 Divident (@14 MSB), @15 Divisor
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	56/8 -> 56 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935, 
;				Divisor  1...255
; 				Ergebnis 0...72057594037927935, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				1470/1302/4 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				80 Bytes
;
;
; div_64x8		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), @8 Rest
; 				@9,10,11,12,13,14,15,16 Divident (@16 MSB), @17 Divisor
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	64/8 -> 64 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615, 
;				Divisor  1...255
; 				Ergebnis 0...18446744073709551615, 
;				Rest     0...254
; 				T=1 bedeutet Divisor = 0
; 				1807/1615/4 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				86 Bytes
;
;
; div_16x16		@0,1 Ergebnis (@1 MSB), @2,3 Rest (@3 MSB), 
; 				@4,5 Divident (@5 MSB), @6,7 Divisor (@7 MSB)
; 				@8 Rest-Erweiterung, @9 Null-Register
; 				Division 	16/16 -> 16 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...65535, 
;				Divisor  1...65535
; 				Ergebnis 0...65535, 
;				Rest     0...65534
; 				T=1 bedeutet Divisor = 0
; 				315/251/5 Cycles 
;				(Divident=65535 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				60 Bytes
;
;
; div_24x16		@0,1,2 Ergebnis (@2 MSB), @3,4 Rest (@4 MSB), 
; 				@5,6,7 Divident (@7 MSB), @8,9 Divisor (@9 MSB)
; 				@10 Rest-Erweiterung, @11 Null-Register
; 				Division 	24/16 -> 24 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...16777215, 
;				Divisor  1...65535
; 				Ergebnis 0...16777215, 
;				Rest     0...65534
; 				T=1 bedeutet Divisor = 0
; 				516/420/5 Cycles 
;				(Divident=16777215 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				66 Bytes
;
;
; div_32x16		@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5 Rest (@5 MSB), 
; 				@6,7,8,9 Divident (@9 MSB), 
; 				@10,11 Divisor (@11 MSB)
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	32/16 -> 32 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...4294967295, 
;				Divisor  1...65535
; 				Ergebnis 0...4294967295, 
;				Rest     0...65534
; 				T=1 bedeutet Divisor = 0
; 				749/621/5 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				72 Bytes
;
;
; div_40x16		@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6 Rest (@6 MSB), 
; 				@7,8,9,10,11 Divident (@11 MSB), 
; 				@12,13 Divisor (@13 MSB)
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	40/16 -> 40 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...1099511627775, 
;				Divisor  1...65535
; 				Ergebnis 0...1099511627775, 
;				Rest     0...65534
; 				T=1 bedeutet Divisor = 0
; 				1014/854/5 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				78 Bytes
;
;
; div_48x16		@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7 Rest (@7 MSB), 
; 				@8,9,10,11,12,13 Divident (@13 MSB), 
; 				@14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	48/16 -> 48 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...281474976710655, 
;				Divisor  1...65535
; 				Ergebnis 0...281474976710655, 
;				Rest     0...65534
; 				T=1 bedeutet Divisor = 0
; 				1311/1119/5 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				84 Bytes
;
;
; div_56x16		@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13,14,15 Divident (@15 MSB), 
; 				@16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	56/16 -> 56 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935, 
;				Divisor  1...65535
; 				Ergebnis 0...72057594037927935, 
;				Rest     0...65534
; 				T=1 bedeutet Divisor = 0
; 				1640/1416/5 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				90 Bytes
;
;
; div_64x16		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	64/16 -> 64 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615, 
;				Divisor  1...65535
; 				Ergebnis 0...18446744073709551615, 
;				Rest     0...65534
; 				T=1 bedeutet Divisor = 0
; 				2001/1745/5 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				96 Bytes
;
;
; div_24x24		@0,1,2 Ergebnis (@2 MSB), 
; 				@3,4,5 Rest (@5 MSB), 
; 				@6,7,8 Divident (@8 MSB), 
; 				@9,10,11 Divisor (@11 MSB)
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	24/24 -> 24 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...16777215, 
;				Divisor  1...16777215
; 				Ergebnis 0...16777215, 
;				Rest     0...16777214
; 				T=1 bedeutet Divisor = 0
; 				590/470/6 Cycles 
;				(Divident=16777215 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				76 Bytes
;
;
; div_32x24		@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5,6 Rest (@6 MSB), 
; 				@7,8,9,10 Divident (@10 MSB), 
; 				@11,12,13 Divisor (@13 MSB)
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	32/24 -> 32 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...4294967295, 
;				Divisor  1...16777215
; 				Ergebnis 0...4294967295, 
;				Rest     0...16777214
; 				T=1 bedeutet Divisor = 0
; 				847/687/6 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				82 Bytes
;
;
; div_40x24		@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7 Rest (@7 MSB), 
; 				@8,9,10,11,12 Divident (@12 MSB), 
; 				@13,14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	40/24 -> 40 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...1099511627775, 
;				Divisor  1...16777215
; 				Ergebnis 0...1099511627775, 
;				Rest     0...16777214
; 				T=1 bedeutet Divisor = 0
; 				1136/936/6 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				88 Bytes
;
;
; div_48x24		@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13,14 Divident (@14 MSB), 
; 				@15,16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	48/24 -> 48 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...281474976710655, 
;				Divisor  1...16777215
; 				Ergebnis 0...281474976710655, 
;				Rest     0...16777214
; 				T=1 bedeutet Divisor = 0
; 				1457/1217/6 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				94 Bytes
;
;
; div_56x24		@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15,16 Divident (@16 MSB), 
; 				@17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	56/24 -> 56 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935, 
;				Divisor  1...16777215
; 				Ergebnis 0...72057594037927935, 
;				Rest     0...16777214
; 				T=1 bedeutet Divisor = 0
; 				1810/1530/6 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				100 Bytes
;
;
; div_64x24		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10 Rest (@10 MSB), 
; 				@11,12,13,14,15,16,17,18 Divident (@18 MSB), 
; 				@19,20,21 Divisor (@21 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	64/24 -> 64 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615, 
;				Divisor  1...16777215
; 				Ergebnis 0...18446744073709551615, 
;				Rest     0...16777214
; 				T=1 bedeutet Divisor = 0
; 				2195/1875/6 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				106 Bytes
;
;
; div_32x32		@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5,6,7 Rest (@7 MSB), 
; 				@8,9,10,11 Divident (@11 MSB), 
; 				@12,13,14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	32/32 -> 32 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...4294967295, 
;				Divisor  1...4294967295
; 				Ergebnis 0...4294967295, 
;				Rest     0...4294967294
; 				T=1 bedeutet Divisor = 0
; 				945/753/7 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				92 Bytes
;
;
; div_40x32		@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13 Divident (@13 MSB), 
; 				@14,15,16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	40/32 -> 40 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...1099511627775, 
;				Divisor  1...4294967295
; 				Ergebnis 0...1099511627775, 
;				Rest     0...4294967294
; 				T=1 bedeutet Divisor = 0
; 				1258/1018/7 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				98 Bytes
;
;
; div_48x32		@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15 Divident (@15 MSB), 
; 				@16,17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	48/32 -> 48 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...281474976710655, 
;				Divisor  1...4294967295
; 				Ergebnis 0...281474976710655, 
;				Rest     0...4294967294
; 				T=1 bedeutet Divisor = 0
; 				1603/1315/7 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				104 Bytes
;
;
; div_56x32		@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10 Rest (@10 MSB), 
; 				@11,12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19,20,21 Divisor (@21 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	56/32 -> 56 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935, 
;				Divisor  1...4294967295
; 				Ergebnis 0...72057594037927935, 
;				Rest     0...4294967294
; 				T=1 bedeutet Divisor = 0
; 				1980/1644/7 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				110 Bytes
;
;
; div_64x32		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17,18,19 Divident (@19 MSB), 
; 				@20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	64/32 -> 64 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615, 
;				Divisor  1...4294967295
; 				Ergebnis 0...18446744073709551615, 
;				Rest     0...4294967294
; 				T=1 bedeutet Divisor = 0
; 				2389/2005/7 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				116 Bytes
;
;
; div_40x40		@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14 Divident (@14 MSB), 
; 				@15,16,17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	40/40 -> 40 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...1099511627775, 
;				Divisor  1...1099511627775
; 				Ergebnis 0...1099511627775, 
;				Rest     0...1099511627774
; 				T=1 bedeutet Divisor = 0
; 				1380/1100/8 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				108 Bytes
;
;
; div_48x40		@0,1,2,3,4,5 Ergebnis (@0 MSB), 
; 				@6,7,8,9,10 Rest (@6 MSB), 
; 				@11,12,13,14,15,16 Divident (@11 MSB), 
; 				@17,18,19,20,21 Divisor (@17 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	48/40 -> 48 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...281474976710655, 
;				Divisor  1...1099511627775
; 				Ergebnis 0...281474976710655, 
;				Rest     0...1099511627774
; 				T=1 bedeutet Divisor = 0
; 				1749/1413/8 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				114 Bytes
;
;
; div_56x40		@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17,18 Divident (@18 MSB), 
; 				@19,20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	56/40 -> 56 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...1099511627775
; 				Ergebnis 0...72057594037927935
; 				Rest     0...1099511627774
; 				T=1 bedeutet Divisor = 0
; 				2150/1758/8 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				120 Bytes
;
;
; div_64x40		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12 Rest (@12 MSB), 
; 				@13,14,15,16,17,18,19,20 Divident (@20 MSB), 
; 				@21,22,23,24,25 Divisor (@25 MSB)
; 				@26 Rest-Erweiterung, @27 Null-Register
; 				Division 	64/40 -> 64 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...1099511627775
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...1099511627774
; 				T=1 bedeutet Divisor = 0
; 				2583/2135/8 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				126 Bytes
;
;
; div_48x48		@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19,20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	48/48 -> 48 bit, Rest 48 bit (unsigned / unsigned)
; 				Divident 0...281474976710655
; 				Divisor  1...281474976710655
; 				Ergebnis 0...281474976710655
; 				Rest     0...281474976710654
; 				T=1 bedeutet Divisor = 0
; 				1895/1511/9 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				124 Bytes
;
;
; div_56x48		@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11,12 Rest (@12 MSB), 
; 				@13,14,15,16,17,18,19 Divident (@19 MSB), 
; 				@20,21,22,23,24,25 Divisor (@25 MSB)
; 				@26 Rest-Erweiterung, @27 Null-Register
; 				Division 	56/48 -> 56 bit, Rest 48 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...281474976710655
; 				Ergebnis 0...72057594037927935
; 				Rest     0...281474976710654
; 				T=1 bedeutet Divisor = 0
; 				2320/1872/9 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				130 Bytes
;
;
; div_64x48		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13 Rest (@13 MSB), 
; 				@14,15,16,17,18,19,20,21 Divident (@21 MSB), 
; 				@22,23,24,25,26,27 Divisor (@27 MSB)
; 				@28 Rest-Erweiterung, @29 Null-Register
; 				Division 	64/48 -> 64 bit, Rest 48 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...281474976710655
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...281474976710654
; 				T=1 bedeutet Divisor = 0
; 				2777/2265/9 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				136 Bytes
;
;
; div_56x56		@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11,12,13 Rest (@13 MSB), 
; 				@14,15,16,17,18,19,20 Divident (@20 MSB), 
; 				@21,22,23,24,25,26,27 Divisor (@27 MSB)
; 				@28 Rest-Erweiterung, @29 Null-Register
; 				Division 	56/56 -> 56 bit, Rest 56 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...72057594037927935
; 				Ergebnis 0...72057594037927935
; 				Rest     0...72057594037927934
; 				T=1 bedeutet Divisor = 0
; 				2490/1986/10 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				140 Bytes
;
;
; div_64x56		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13,14 Rest (@14 MSB), 
; 				@15,16,17,18,19,20,21,22 Divident (@22 MSB), 
; 				@23,24,25,26,27,28,29 Divisor (@29 MSB)
; 				@30 Rest-Erweiterung, @31 Null-Register
; 				Division 	64/56 -> 64 bit, Rest 56 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...72057594037927935
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...72057594037927934
; 				T=1 bedeutet Divisor = 0
; 				2972/2396/11 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				148 Bytes
;
;
; div_64x64		@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13,14,15 Rest (@15 MSB), 
; 				@16,17,18,19,20,21,22,23 Divident (@23 MSB), 
; 				@24,25,26,27,28,29,30,31 Divisor (@31 MSB)
; 				@29 Divisor-Puffer
; 				@30 Rest-Erweiterung
; 				@31 Null-Register
; 				@32 Ram-Puffer-24 fuer Divisor (3 Bytes in SRAM)
; 				Division 	64/64 -> 64 bit, Rest 64 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...18446744073709551615
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...18446744073709551614
; 				T=1 bedeutet Divisor = 0
; 				3940/2916/12 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				194 Bytes
;
;
;
;=================================================================================
;=== div signed ==================================================================
;=================================================================================
; div_8x8_s		@0 Ergebnis, @1 Rest, @2 Divident, @3 Divisor
; 				Division 	8/8 -> 8 bit, Rest 8 bit (signed / signed)
; 				Divident -128...127
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -128...128
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				101/87/4 Cycles 
;				(Divident=127 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				60 Bytes
;
;
; div_16x8_s	@0,1 Ergebnis (@1 MSB), @2 Rest
; 				@3,4 Divident (@4 MSB), @5 Divisor
; 				@6 Rest-Erweiterung, @7 Null-Register
; 				Division 	16/8 -> 16 bit, Rest 8 bit (signed / signed)
; 				Divident -32768...32767
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -32768...32768
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				271/226/4 Cycles 
;				(Divident=32767 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				92 Bytes
;
;
; div_24x8_s	@0,1,2 Ergebnis (@2 MSB), @3 Rest
; 				@4,5,6 Divident (@6 MSB), @7 Divisor
; 				@8 Rest-Erweiterung, @9 Null-Register
; 				Division 	24/8 -> 24 bit, Rest 8 bit (signed / signed)
; 				Divident -8388608...8388607
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -8388608...8388608
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				448/379/4 Cycles 
;				(Divident=8388607 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				106 Bytes
;
;
; div_32x8_s	@0,1,2,3 Ergebnis (@3 MSB), @4 Rest
; 				@5,6,7,8 Divident (@8 MSB), @9 Divisor
; 				@10 Rest-Erweiterung, @11 Null-Register
; 				Division 	32/8 -> 32 bit, Rest 8 bit (signed / signed)
; 				Divident -2147483648...2147483647
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -2147483648...2147483648
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				657/564/4 Cycles 
;				(Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				120 Bytes
;
;
; div_40x8_s	@0,1,2,3,4 Ergebnis (@4 MSB), @5 Rest
; 				@6,7,8,9,10 Divident (@10 MSB), @11 Divisor
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	40/8 -> 40 bit, Rest 8 bit (signed / signed)
; 				Divident -549755813888...549755813887
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -549755813888...549755813888
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				899/782/5 Cycles 
;				(Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				136 Bytes
;
;
; div_48x8_s	@0,1,2,3,4,5 Ergebnis (@5 MSB), @6 Rest
; 				@7,8,9,10,11,12 Divident (@12 MSB), @13 Divisor
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	48/8 -> 48 bit, Rest 8 bit (signed / signed)
; 				Divident -140737488355328...140737488355327
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -140737488355328...140737488355328
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				1172/1031/5 Cycles 
;				(Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				150 Bytes
;
;
; div_56x8_s	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), @7 Rest
; 				@8,9,10,11,12,13,14 Divident (@14 MSB), @15 Divisor
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	56/8 -> 56 bit, Rest 8 bit (signed / signed)
; 				Divident -36028797018963968...36028797018963967
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -36028797018963968...36028797018963968
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				1477/1312/5 Cycles 
;				(Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				164 Bytes
;
;
; div_64x8_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), @8 Rest
; 				@9,10,11,12,13,14,15,16 Divident (@16 MSB), @17 Divisor
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	64/8 -> 64 bit, Rest 8 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -128...-1, 1...127
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -127...127
; 				T=1 bedeutet Divisor = 0
; 				1814/1625/5 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				178 Bytes
;
;
; div_16x16_s	@0,1 Ergebnis (@1 MSB), @2,3 Rest (@3 MSB), 
; 				@4,5 Divident (@5 MSB), @6,7 Divisor (@7 MSB)
; 				@8 Rest-Erweiterung, @9 Null-Register
; 				Division 	16/16 -> 16 bit, Rest 16 bit (signed / signed)
; 				Divident -32768...32767
; 				Divisor  -32768...-1, 1...32767
; 				Ergebnis -32768...32768
; 				Rest     -32767...32767
; 				T=1 bedeutet Divisor = 0
; 				320/260/5 Cycles 
;				(Divident=32767 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				118 Bytes
;
;
; div_24x16_s	@0,1,2 Ergebnis (@2 MSB), @3,4 Rest (@4 MSB), 
; 				@5,6,7 Divident (@7 MSB), @8,9 Divisor (@9 MSB)
; 				@10 Rest-Erweiterung, @11 Null-Register
; 				Division 	24/16 -> 24 bit, Rest 16 bit (signed / signed)
; 				Divident -8388608...8388607
; 				Divisor  -32768...-1, 1...32767
; 				Ergebnis -8388608...8388608
; 				Rest     -32767...32767
; 				T=1 bedeutet Divisor = 0
; 				521/429/5 Cycles 
;				(Divident=8388607 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				132 Bytes
;
;
; div_32x16_s	@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5 Rest (@5 MSB), 
; 				@6,7,8,9 Divident (@9 MSB), 
; 				@10,11 Divisor (@11 MSB)
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	32/16 -> 32 bit, Rest 16 bit (signed / signed)
; 				Divident -2147483648...2147483647
; 				Divisor  -32768...-1, 1...32767
; 				Ergebnis -2147483648...2147483648
; 				Rest     -32767...32767
; 				T=1 bedeutet Divisor = 0
; 				755/631/6 Cycles 
;				(Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				148 Bytes
;
;
; div_40x16_s	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6 Rest (@6 MSB), 
; 				@7,8,9,10,11 Divident (@11 MSB), 
; 				@12,13 Divisor (@13 MSB)
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	40/16 -> 40 bit, Rest 16 bit (signed / signed)
; 				Divident -549755813888...549755813887
; 				Divisor  -32768...-1, 1...32767
; 				Ergebnis -549755813888...549755813888
; 				Rest     -32767...32767
; 				T=1 bedeutet Divisor = 0
; 				1020/864/6 Cycles 
;				(Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				162 Bytes
;
;
; div_48x16_s	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7 Rest (@7 MSB), 
; 				@8,9,10,11,12,13 Divident (@13 MSB), 
; 				@14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	48/16 -> 48 bit, Rest 16 bit (signed / signed)
; 				Divident -140737488355328...140737488355327
; 				Divisor  -32768...-1, 1...32767
; 				Ergebnis -140737488355328...140737488355328
; 				Rest     -32767...32767
; 				T=1 bedeutet Divisor = 0
; 				1317/1129/6 Cycles 
;				(Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				176 Bytes
;
;
; div_56x16_s	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13,14,15 Divident (@15 MSB), 
; 				@16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	56/16 -> 56 bit, Rest 16 bit (signed / signed)
; 				Divident -36028797018963968...36028797018963967
; 				Divisor  -32768...-1, 1...32767
; 				Ergebnis -36028797018963968...36028797018963968
; 				Rest     -32767...32767
; 				T=1 bedeutet Divisor = 0
; 				1646/1426/6 Cycles 
;				(Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				190 Bytes
;
;
; div_64x16_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	64/16 -> 64 bit, Rest 16 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -32768...-1, 1...32767
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -32767...32767
; 				T=1 bedeutet Divisor = 0
; 				2007/1755/6 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				204 Bytes
;
;
; div_24x24_s	@0,1,2 Ergebnis (@2 MSB), 
; 				@3,4,5 Rest (@5 MSB), 
; 				@6,7,8 Divident (@8 MSB), 
; 				@9,10,11 Divisor (@11 MSB)
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	24/24 -> 24 bit, Rest 24 bit (signed / signed)
; 				Divident -8388608...8388607
; 				Divisor  -8388608...-1, 1...8388607
; 				Ergebnis -8388608...8388608
; 				Rest     -8388607...8388607
; 				T=1 bedeutet Divisor = 0
; 				595/480/7 Cycles 
;				(Divident=8388607 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				152 Bytes
;
;
; div_32x24_s	@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5,6 Rest (@6 MSB), 
; 				@7,8,9,10 Divident (@10 MSB), 
; 				@11,12,13 Divisor (@13 MSB)
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	32/24 -> 32 bit, Rest 24 bit (signed / signed)
; 				Divident -2147483648...2147483647
; 				Divisor  -8388608...-1, 1...8388607
; 				Ergebnis -2147483648...2147483648
; 				Rest     -8388607...8388607
; 				T=1 bedeutet Divisor = 0
; 				852/697/7 Cycles 
;				(Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				166 Bytes
;
;
; div_40x24_s	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7 Rest (@7 MSB), 
; 				@8,9,10,11,12 Divident (@12 MSB), 
; 				@13,14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	40/24 -> 40 bit, Rest 24 bit (signed / signed)
; 				Divident -549755813888...549755813887
; 				Divisor  -8388608...-1, 1...8388607
; 				Ergebnis -549755813888...549755813888
; 				Rest     -8388607...8388607
; 				T=1 bedeutet Divisor = 0
; 				1141/946/7 Cycles 
;				(Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				180 Bytes
;
;
; div_48x24_s	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13,14 Divident (@14 MSB), 
; 				@15,16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	48/24 -> 48 bit, Rest 24 bit (signed / signed)
; 				Divident -140737488355328...140737488355327
; 				Divisor  -8388608...-1, 1...8388607
; 				Ergebnis -140737488355328...140737488355328
; 				Rest     -8388607...8388607
; 				T=1 bedeutet Divisor = 0
; 				1462/1227/7 Cycles 
;				(Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				194 Bytes
;
;
; div_56x24_s	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15,16 Divident (@16 MSB), 
; 				@17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	56/24 -> 56 bit, Rest 24 bit (signed / signed)
; 				Divident -36028797018963968...36028797018963967
; 				Divisor  -8388608...-1, 1...8388607
; 				Ergebnis -36028797018963968...36028797018963968
; 				Rest     -8388607...8388607
; 				T=1 bedeutet Divisor = 0
; 				1815/1540/7 Cycles 
;				(Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				208 Bytes
;
;
; div_64x24_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10 Rest (@10 MSB), 
; 				@11,12,13,14,15,16,17,18 Divident (@18 MSB), 
; 				@19,20,21 Divisor (@21 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	64/24 -> 64 bit, Rest 24 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -8388608...-1, 1...8388607
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -8388607...8388607
; 				T=1 bedeutet Divisor = 0
; 				2200/1885/7 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				222 Bytes
;
;
; div_32x32_s	@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5,6,7 Rest (@7 MSB), 
; 				@8,9,10,11 Divident (@11 MSB), 
; 				@12,13,14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	32/32 -> 32 bit, Rest 32 bit (signed / signed)
; 				Divident -2147483648...2147483647
; 				Divisor  -2147483648...-1, 1...2147483647
; 				Ergebnis -2147483648...2147483648
; 				Rest     -2147483647...2147483647
; 				T=1 bedeutet Divisor = 0
; 				949/763/8 Cycles 
;				(Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				184 Bytes
;
;
; div_40x32_s	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13 Divident (@13 MSB), 
; 				@14,15,16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	40/32 -> 40 bit, Rest 32 bit (signed / signed)
; 				Divident -549755813888...549755813887
; 				Divisor  -2147483648...-1, 1...2147483647
; 				Ergebnis -549755813888...549755813888
; 				Rest     -2147483647...2147483647
; 				T=1 bedeutet Divisor = 0
; 				1262/1028/8 Cycles 
;				(Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				198 Bytes
;
;
; div_48x32_s	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15 Divident (@15 MSB), 
; 				@16,17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	48/32 -> 48 bit, Rest 32 bit (signed / signed)
; 				Divident -140737488355328...140737488355327
; 				Divisor  -2147483648...-1, 1...2147483647
; 				Ergebnis -140737488355328...140737488355328
; 				Rest     -2147483647...2147483647
; 				T=1 bedeutet Divisor = 0
; 				1607/1325/8 Cycles 
;				(Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				212 Bytes
;
;
; div_56x32_s	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10 Rest (@10 MSB), 
; 				@11,12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19,20,21 Divisor (@21 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	56/32 -> 56 bit, Rest 32 bit (signed / signed)
; 				Divident -36028797018963968...36028797018963967
; 				Divisor  -2147483648...-1, 1...2147483647
; 				Ergebnis -36028797018963968...36028797018963968
; 				Rest     -2147483647...2147483647
; 				T=1 bedeutet Divisor = 0
; 				1984/1654/8 Cycles 
;				(Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				226 Bytes
;
;
; div_64x32_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17,18,19 Divident (@19 MSB), 
; 				@20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	64/32 -> 64 bit, Rest 32 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -2147483648...-1, 1...2147483647
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -2147483647...2147483647
; 				T=1 bedeutet Divisor = 0
; 				2393/2015/8 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				240 Bytes
;
;
; div_40x40_s	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14 Divident (@14 MSB), 
; 				@15,16,17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	40/40 -> 40 bit, Rest 40 bit (signed / signed)
; 				Divident -549755813888...549755813887
; 				Divisor  -549755813888...-1, 1...549755813887
; 				Ergebnis -549755813888...549755813888
; 				Rest     -549755813887...549755813887
; 				T=1 bedeutet Divisor = 0
; 				1383/1110/9 Cycles 
;				(Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				216 Bytes
;
;
; div_48x40_s	@0,1,2,3,4,5 Ergebnis (@0 MSB), 
; 				@6,7,8,9,10 Rest (@6 MSB), 
; 				@11,12,13,14,15,16 Divident (@11 MSB), 
; 				@17,18,19,20,21 Divisor (@17 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	48/40 -> 48 bit, Rest 40 bit (signed / signed)
; 				Divident -140737488355328...140737488355327
; 				Divisor  -549755813888...-1, 1...549755813887
; 				Ergebnis -140737488355328...140737488355328
; 				Rest     -549755813887...549755813887
; 				T=1 bedeutet Divisor = 0
; 				1752/1423/9 Cycles 
;				(Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				230 Bytes
;
;
; div_56x40_s	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17,18 Divident (@18 MSB), 
; 				@19,20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	56/40 -> 56 bit, Rest 40 bit (signed / signed)
; 				Divident -36028797018963968...36028797018963967
; 				Divisor  -549755813888...-1, 1...549755813887
; 				Ergebnis -36028797018963968...36028797018963968
; 				Rest     -549755813887...549755813887
; 				T=1 bedeutet Divisor = 0
; 				2153/1768/9 Cycles 
;				(Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				244 Bytes
;
;
; div_64x40_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12 Rest (@12 MSB), 
; 				@13,14,15,16,17,18,19,20 Divident (@20 MSB), 
; 				@21,22,23,24,25 Divisor (@25 MSB)
; 				@26 Rest-Erweiterung, @27 Null-Register
; 				Division 	64/40 -> 64 bit, Rest 40 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -549755813888...-1, 1...549755813887
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -549755813887...549755813887
; 				T=1 bedeutet Divisor = 0
; 				2586/2145/9 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				258 Bytes
;
;
; div_48x48_s	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19,20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	48/48 -> 48 bit, Rest 48 bit (signed / signed)
; 				Divident -140737488355328...140737488355327
; 				Divisor  -140737488355328...-1, 1...140737488355327
; 				Ergebnis -140737488355328...140737488355328
; 				Rest     -140737488355327...140737488355327
; 				T=1 bedeutet Divisor = 0
; 				1897/1521/10 Cycles 
;				(Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				248 Bytes
;
;
; div_56x48_s	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11,12 Rest (@12 MSB), 
; 				@13,14,15,16,17,18,19 Divident (@19 MSB), 
; 				@20,21,22,23,24,25 Divisor (@25 MSB)
; 				@26 Rest-Erweiterung, @27 Null-Register
; 				Division 	56/48 -> 56 bit, Rest 48 bit (signed / signed)
; 				Divident -36028797018963968...36028797018963967
; 				Divisor  -140737488355328...-1, 1...140737488355327
; 				Ergebnis -36028797018963968...36028797018963968
; 				Rest     -140737488355327...140737488355327
; 				T=1 bedeutet Divisor = 0
; 				2322/1882/10 Cycles 
;				(Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				262 Bytes
;
;
; div_64x48_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13 Rest (@13 MSB), 
; 				@14,15,16,17,18,19,20,21 Divident (@21 MSB), 
; 				@22,23,24,25,26,27 Divisor (@27 MSB)
; 				@28 Rest-Erweiterung, @29 Null-Register
; 				Division 	64/48 -> 64 bit, Rest 48 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -140737488355328...-1, 1...140737488355327
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -140737488355327...140737488355327
; 				T=1 bedeutet Divisor = 0
; 				2779/2275/10 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				276 Bytes
;
;
; div_56x56_s	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11,12,13 Rest (@13 MSB), 
; 				@14,15,16,17,18,19,20 Divident (@20 MSB), 
; 				@21,22,23,24,25,26,27 Divisor (@27 MSB)
; 				@28 Rest-Erweiterung, @29 Null-Register
; 				Division 	56/56 -> 56 bit, Rest 56 bit (signed / signed)
; 				Divident -36028797018963968...36028797018963967
; 				Divisor  -36028797018963968...-1, 1...36028797018963967
; 				Ergebnis -36028797018963968...36028797018963968
; 				Rest     -36028797018963967...36028797018963967
; 				T=1 bedeutet Divisor = 0
; 				2491/1996/11 Cycles 
;				(Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				280 Bytes
;
;
; div_64x56_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13,14 Rest (@14 MSB), 
; 				@15,16,17,18,19,20,21,22 Divident (@22 MSB), 
; 				@23,24,25,26,27,28,29 Divisor (@29 MSB)
; 				@30 Rest-Erweiterung, @31 Null-Register
; 				Division 	64/56 -> 64 bit, Rest 56 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -36028797018963968...-1, 1...36028797018963967
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -36028797018963967...36028797018963967
; 				T=1 bedeutet Divisor = 0
; 				2972/2405/11 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				294 Bytes
;
;
; div_64x64_s	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13,14,15 Rest (@15 MSB), 
; 				@16,17,18,19,20,21,22,23 Divident (@23 MSB), 
; 				@24,25,26,27,28,29,30,31 Divisor (@31 MSB)
; 				@29 Divisor-Puffer
; 				@30 Rest-Erweiterung
; 				@31 Null-Register
; 				@32 Ram-Puffer-24 fuer Divisor (3 Bytes in SRAM)
; 				Division 	64/64 -> 64 bit, Rest 64 bit (signed / signed)
; 				Divident -9223372036854775808...9223372036854775807
; 				Divisor  -9223372036854775808...-1, 1...9223372036854775807
; 				Ergebnis -9223372036854775808...9223372036854775808
; 				Rest     -9223372036854775807...9223372036854775807
; 				T=1 bedeutet Divisor = 0
; 				3933/2925/12 Cycles 
;				(Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
; 				348 Bytes
;
;
;=================================================================================
;=== NEG-Macro ===================================================================
;=================================================================================
; neg16		@0,1 Data (@1 MSB), @2 temp, 5c,10b
;
; neg24		@0-2 Data (@2 MSB), @3 temp, 7c,14b
;
; neg32		@0-3 Data (@3 MSB), @4 temp, 9c,18b
;
; neg40		@0-4 Data (@4 MSB), @5 temp, 11c,22b
;
; neg48		@0-5 Data (@5 MSB), @6 temp, 13c,26b
;
; neg56		@0-6 Data (@6 MSB), @7 temp, 15c,30b
;
; neg64		@0-7 Data (@7 MSB), @8 temp, 17c,34b
;
;
;=================================================================================
;=== div unsigned kern ===========================================================
;=== wenn Divisor garantiert !=0 =================================================
;=================================================================================
; div_8x8__		@0 Ergebnis, @1 Rest, @2 Divident, @3 Divisor
; 				Division 	8/8 -> 8 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...255
; 				Divisor  1...255
; 				Ergebnis 0...255
; 				Rest     0...254
; 				90/74 Cycles 
;				(Divident=255 Divisor=1/Divident=0 Divisor=1),
; 				26 Bytes
;
;
; div_16x8__	@0,1 Ergebnis (@1 MSB), @2 Rest
; 				@3,4 Divident (@4 MSB), @5 Divisor
; 				@6 Rest-Erweiterung, @7 Null-Register
; 				Division 	16/8 -> 16 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...65535
; 				Divisor  1...255
; 				Ergebnis 0...65535
; 				Rest     0...254
; 				261/213 Cycles 
;				(Divident=65535 Divisor=1/Divident=0 Divisor=1),
; 				42 Bytes
;
;
; div_24x8__	@0,1,2 Ergebnis (@2 MSB), @3 Rest
; 				@4,5,6 Divident (@6 MSB), @7 Divisor
; 				@8 Rest-Erweiterung, @9 Null-Register
; 				Division 	24/8 -> 24 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...16777215
; 				Divisor  1...255
; 				Ergebnis 0...16777215
; 				Rest     0...254
; 				438/366 Cycles 
;				(Divident=16777215 Divisor=1/Divident=0 Divisor=1),
; 				48 Bytes
;
;
; div_32x8__	@0,1,2,3 Ergebnis (@3 MSB), @4 Rest
; 				@5,6,7,8 Divident (@8 MSB), @9 Divisor
; 				@10 Rest-Erweiterung, @11 Null-Register
; 				Division 	32/8 -> 32 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...4294967295
; 				Divisor  1...255
; 				Ergebnis 0...4294967295
; 				Rest     0...254
; 				647/551 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
; 				54 Bytes
;
;
; div_40x8__	@0,1,2,3,4 Ergebnis (@4 MSB), @5 Rest
; 				@6,7,8,9,10 Divident (@10 MSB), @11 Divisor
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	40/8 -> 40 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...1099511627775
; 				Divisor  1...255
; 				Ergebnis 0...1099511627775
; 				Rest     0...254
; 				888/768 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
; 				60 Bytes
;
;
; div_48x8__	@0,1,2,3,4,5 Ergebnis (@5 MSB), @6 Rest
; 				@7,8,9,10,11,12 Divident (@12 MSB), @13 Divisor
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	48/8 -> 48 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...281474976710655
; 				Divisor  1...255
; 				Ergebnis 0...281474976710655
; 				Rest     0...254
; 				1161/1017 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
; 				66 Bytes
;
;
; div_56x8__	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), @7 Rest
; 				@8,9,10,11,12,13,14 Divident (@14 MSB), @15 Divisor
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	56/8 -> 56 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...255
; 				Ergebnis 0...72057594037927935
; 				Rest     0...254
; 				1466/1298 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
; 				72 Bytes
;
;
; div_64x8__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), @8 Rest
; 				@9,10,11,12,13,14,15,16 Divident (@16 MSB), @17 Divisor
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	64/8 -> 64 bit, Rest 8 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...255
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...254
; 				1803/1611 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				78 Bytes
;
;
; div_16x16__	@0,1 Ergebnis (@1 MSB), @2,3 Rest (@3 MSB), 
; 				@4,5 Divident (@5 MSB), @6,7 Divisor (@7 MSB)
; 				@8 Rest-Erweiterung, @9 Null-Register
; 				Division 	16/16 -> 16 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...65535
; 				Divisor  1...65535
; 				Ergebnis 0...65535
; 				Rest     0...65534
; 				310/246 Cycles 
;				(Divident=65535 Divisor=1/Divident=0 Divisor=1),
; 				50 Bytes
;
;
; div_24x16__	@0,1,2 Ergebnis (@2 MSB), @3,4 Rest (@4 MSB), 
; 				@5,6,7 Divident (@7 MSB), @8,9 Divisor (@9 MSB)
; 				@10 Rest-Erweiterung, @11 Null-Register
; 				Division 	24/16 -> 24 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...16777215
; 				Divisor  1...65535
; 				Ergebnis 0...16777215
; 				Rest     0...65534
; 				511/415 Cycles 
;				(Divident=16777215 Divisor=1/Divident=0 Divisor=1),
; 				56 Bytes
;
;
; div_32x16__	@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5 Rest (@5 MSB), 
; 				@6,7,8,9 Divident (@9 MSB), 
; 				@10,11 Divisor (@11 MSB)
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	32/16 -> 32 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...4294967295
; 				Divisor  1...65535
; 				Ergebnis 0...4294967295
; 				Rest     0...65534
; 				744/616 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
; 				62 Bytes
;
;
; div_40x16__	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6 Rest (@6 MSB), 
; 				@7,8,9,10,11 Divident (@11 MSB), 
; 				@12,13 Divisor (@13 MSB)
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	40/16 -> 40 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...1099511627775
; 				Divisor  1...65535
; 				Ergebnis 0...1099511627775
; 				Rest     0...65534
; 				1009/849 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
; 				68 Bytes
;
;
; div_48x16__	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7 Rest (@7 MSB), 
; 				@8,9,10,11,12,13 Divident (@13 MSB), 
; 				@14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	48/16 -> 48 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...281474976710655
; 				Divisor  1...65535
; 				Ergebnis 0...281474976710655
; 				Rest     0...65534
; 				1306/1114 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
; 				74 Bytes
;
;
; div_56x16__	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13,14,15 Divident (@15 MSB), 
; 				@16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	56/16 -> 56 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...65535
; 				Ergebnis 0...72057594037927935
; 				Rest     0...65534
; 				1635/1411 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
; 				80 Bytes
;
;
; div_64x16__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	64/16 -> 64 bit, Rest 16 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...65535
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...65534
; 				1996/1740 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				86 Bytes
;
;
; div_24x24__	@0,1,2 Ergebnis (@2 MSB), 
; 				@3,4,5 Rest (@5 MSB), 
; 				@6,7,8 Divident (@8 MSB), 
; 				@9,10,11 Divisor (@11 MSB)
; 				@12 Rest-Erweiterung, @13 Null-Register
; 				Division 	24/24 -> 24 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...16777215
; 				Divisor  1...16777215
; 				Ergebnis 0...16777215
; 				Rest     0...16777214
; 				584/464 Cycles 
;				(Divident=16777215 Divisor=1/Divident=0 Divisor=1),
; 				64 Bytes
;
;
; div_32x24__	@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5,6 Rest (@6 MSB), 
; 				@7,8,9,10 Divident (@10 MSB), 
; 				@11,12,13 Divisor (@13 MSB)
; 				@14 Rest-Erweiterung, @15 Null-Register
; 				Division 	32/24 -> 32 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...4294967295
; 				Divisor  1...16777215
; 				Ergebnis 0...4294967295
; 				Rest     0...16777214
; 				841/681 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
; 				70 Bytes
;
;
; div_40x24__	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7 Rest (@7 MSB), 
; 				@8,9,10,11,12 Divident (@12 MSB), 
; 				@13,14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	40/24 -> 40 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...1099511627775
; 				Divisor  1...16777215
; 				Ergebnis 0...1099511627775
; 				Rest     0...16777214
; 				1130/930 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
; 				76 Bytes
;
;
; div_48x24__	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13,14 Divident (@14 MSB), 
; 				@15,16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	48/24 -> 48 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...281474976710655
; 				Divisor  1...16777215
; 				Ergebnis 0...281474976710655
; 				Rest     0...16777214
; 				1451/1211 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
; 				82 Bytes
;
;
; div_56x24__	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15,16 Divident (@16 MSB), 
; 				@17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	56/24 -> 56 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...16777215
; 				Ergebnis 0...72057594037927935
; 				Rest     0...16777214
; 				1804/1524 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
; 				88 Bytes
;
;
; div_64x24__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10 Rest (@10 MSB), 
; 				@11,12,13,14,15,16,17,18 Divident (@18 MSB), 
; 				@19,20,21 Divisor (@21 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	64/24 -> 64 bit, Rest 24 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...16777215
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...16777214
; 				2189/1869 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				94 Bytes
;
;
; div_32x32__	@0,1,2,3 Ergebnis (@3 MSB), 
; 				@4,5,6,7 Rest (@7 MSB), 
; 				@8,9,10,11 Divident (@11 MSB), 
; 				@12,13,14,15 Divisor (@15 MSB)
; 				@16 Rest-Erweiterung, @17 Null-Register
; 				Division 	32/32 -> 32 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...4294967295
; 				Divisor  1...4294967295
; 				Ergebnis 0...4294967295
; 				Rest     0...4294967294
; 				938/746 Cycles 
;				(Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
; 				78 Bytes
;
;
; div_40x32__	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7,8 Rest (@8 MSB), 
; 				@9,10,11,12,13 Divident (@13 MSB), 
; 				@14,15,16,17 Divisor (@17 MSB)
; 				@18 Rest-Erweiterung, @19 Null-Register
; 				Division 	40/32 -> 40 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...1099511627775
; 				Divisor  1...4294967295
; 				Ergebnis 0...1099511627775
; 				Rest     0...4294967294
; 				1251/1011 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
; 				84 Bytes
;
;
; div_48x32__	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14,15 Divident (@15 MSB), 
; 				@16,17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	48/32 -> 48 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...281474976710655
; 				Divisor  1...4294967295
; 				Ergebnis 0...281474976710655
; 				Rest     0...4294967294
; 				1596/1308 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
; 				90 Bytes
;
;
; div_56x32__	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10 Rest (@10 MSB), 
; 				@11,12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19,20,21 Divisor (@21 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	56/32 -> 56 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...4294967295
; 				Ergebnis 0...72057594037927935
; 				Rest     0...4294967294
; 				1973/1637 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
; 				96 Bytes
;
;
; div_64x32__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17,18,19 Divident (@19 MSB), 
; 				@20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	64/32 -> 64 bit, Rest 32 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...4294967295
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...4294967294
; 				2382/1998 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				102 Bytes
;
;
; div_40x40__	@0,1,2,3,4 Ergebnis (@4 MSB), 
; 				@5,6,7,8,9 Rest (@9 MSB), 
; 				@10,11,12,13,14 Divident (@14 MSB), 
; 				@15,16,17,18,19 Divisor (@19 MSB)
; 				@20 Rest-Erweiterung, @21 Null-Register
; 				Division 	40/40 -> 40 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...1099511627775
; 				Divisor  1...1099511627775
; 				Ergebnis 0...1099511627775
; 				Rest     0...1099511627774
; 				1372/1092 Cycles 
;				(Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
; 				92 Bytes
;
;
; div_48x40__	@0,1,2,3,4,5 Ergebnis (@0 MSB), 
; 				@6,7,8,9,10 Rest (@6 MSB), 
; 				@11,12,13,14,15,16 Divident (@11 MSB), 
; 				@17,18,19,20,21 Divisor (@17 MSB)
; 				@22 Rest-Erweiterung, @23 Null-Register
; 				Division 	48/40 -> 48 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...281474976710655
; 				Divisor  1...1099511627775
; 				Ergebnis 0...281474976710655
; 				Rest     0...1099511627774
; 				1741/1405 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
; 				98 Bytes
;
;
; div_56x40__	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17,18 Divident (@18 MSB), 
; 				@19,20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	56/40 -> 56 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...1099511627775
; 				Ergebnis 0...72057594037927935
; 				Rest     0...1099511627774
; 				2142/1750 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
; 				104 Bytes
;
;
; div_64x40__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12 Rest (@12 MSB), 
; 				@13,14,15,16,17,18,19,20 Divident (@20 MSB), 
; 				@21,22,23,24,25 Divisor (@25 MSB)
; 				@26 Rest-Erweiterung, @27 Null-Register
; 				Division 	64/40 -> 64 bit, Rest 40 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...1099511627775
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...1099511627774
; 				2575/2127 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				110 Bytes
;
;
; div_48x48__	@0,1,2,3,4,5 Ergebnis (@5 MSB), 
; 				@6,7,8,9,10,11 Rest (@11 MSB), 
; 				@12,13,14,15,16,17 Divident (@17 MSB), 
; 				@18,19,20,21,22,23 Divisor (@23 MSB)
; 				@24 Rest-Erweiterung, @25 Null-Register
; 				Division 	48/48 -> 48 bit, Rest 48 bit (unsigned / unsigned)
; 				Divident 0...281474976710655
; 				Divisor  1...281474976710655
; 				Ergebnis 0...281474976710655
; 				Rest     0...281474976710654
; 				1886/1502 Cycles 
;				(Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
; 				106 Bytes
;
;
; div_56x48__	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11,12 Rest (@12 MSB), 
; 				@13,14,15,16,17,18,19 Divident (@19 MSB), 
; 				@20,21,22,23,24,25 Divisor (@25 MSB)
; 				@26 Rest-Erweiterung, @27 Null-Register
; 				Division 	56/48 -> 56 bit, Rest 48 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...281474976710655
; 				Ergebnis 0...72057594037927935
; 				Rest     0...281474976710654
; 				2311/1863 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
; 				112 Bytes
;
;
; div_64x48__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13 Rest (@13 MSB), 
; 				@14,15,16,17,18,19,20,21 Divident (@21 MSB), 
; 				@22,23,24,25,26,27 Divisor (@27 MSB)
; 				@28 Rest-Erweiterung, @29 Null-Register
; 				Division 	64/48 -> 64 bit, Rest 48 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...281474976710655
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...281474976710654
; 				2768/2256 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				118 Bytes
;
;
; div_56x56__	@0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
; 				@7,8,9,10,11,12,13 Rest (@13 MSB), 
; 				@14,15,16,17,18,19,20 Divident (@20 MSB), 
; 				@21,22,23,24,25,26,27 Divisor (@27 MSB)
; 				@28 Rest-Erweiterung, @29 Null-Register
; 				Division 	56/56 -> 56 bit, Rest 56 bit (unsigned / unsigned)
; 				Divident 0...72057594037927935
; 				Divisor  1...72057594037927935
; 				Ergebnis 0...72057594037927935
; 				Rest     0...72057594037927934
; 				2480/1976 Cycles 
;				(Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
; 				120 Bytes
;
;
; div_64x56__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13,14 Rest (@14 MSB), 
; 				@15,16,17,18,19,20,21,22 Divident (@22 MSB), 
; 				@23,24,25,26,27,28,29 Divisor (@29 MSB)
; 				@30 Rest-Erweiterung, @31 Null-Register
; 				Division 	64/56 -> 64 bit, Rest 56 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...72057594037927935
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...72057594037927934
; 				2961/2385 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				126 Bytes
;
;
; div_64x64__	@0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
; 				@8,9,10,11,12,13,14,15 Rest (@15 MSB), 
; 				@16,17,18,19,20,21,22,23 Divident (@23 MSB), 
; 				@24,25,26,27,28,29,30,31 Divisor (@31 MSB)
; 				@29 Divisor-Puffer
; 				@30 Rest-Erweiterung
; 				@31 Null-Register
; 				@32 Ram-Puffer-24 fuer Divisor (3 Bytes in SRAM)
; 				Division 	64/64 -> 64 bit, Rest 64 bit (unsigned / unsigned)
; 				Divident 0...18446744073709551615
; 				Divisor  1...18446744073709551615
; 				Ergebnis 0...18446744073709551615
; 				Rest     0...18446744073709551614
; 				3928/2904 Cycles 
;				(Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
; 				170 Bytes
;
;
;=================================================================================
;=================================================================================
;=================================================================================

 #ifndef _DIVISION_
 #define _DIVISION_


;
;=================================================================================
;=== div unsigned ================================================================
;=================================================================================
.macro div_8x8	; @0 Ergebnis, @1 Rest, @2 Divident, @3 Divisor
		; Division 	8/8 -> 8 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...255
		; Divisor  1...255
		; Ergebnis 0...255
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 94/78/4 Cycles (Divident=255 Divisor=1/Divident=0 Divisor=1/Divisor=0),  
		; 34 Bytes
	set
	tst @3		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_8x8__ @0,@1,@2,@3
 end:
.endm

.macro div_16x8	; @0,1 Ergebnis (@1 MSB), @2 Rest
				; @3,4 Divident (@4 MSB), @5 Divisor
				; @6 Rest-Erweiterung, @7 Null-Register
		; Division 	16/8 -> 16 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...65535
		; Divisor  1...255
		; Ergebnis 0...65535
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 265/217/4 Cycles (Divident=65535 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 50 Bytes
	set
	tst @5		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_16x8__ @0,@1,@2,@3,@4,@5,@6,@7
 end:
.endm

.macro div_24x8	; @0,1,2 Ergebnis (@2 MSB), @3 Rest
				; @4,5,6 Divident (@6 MSB), @7 Divisor
				; @8 Rest-Erweiterung, @9 Null-Register
		; Division 	24/8 -> 24 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...16777215
		; Divisor  1...255
		; Ergebnis 0...16777215
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 442/370/4 Cycles (Divident=16777215 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 56 Bytes
	set
	tst @7		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_24x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9
 end:
.endm

.macro div_32x8	; @0,1,2,3 Ergebnis (@3 MSB), @4 Rest
				; @5,6,7,8 Divident (@8 MSB), @9 Divisor
				; @10 Rest-Erweiterung, @11 Null-Register
		; Division 	32/8 -> 32 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...255
		; Ergebnis 0...4294967295
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 651/555/4 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 62 Bytes
	set
	tst @9		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_32x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11
 end:
.endm

.macro div_40x8	; @0,1,2,3,4 Ergebnis (@4 MSB), @5 Rest
				; @6,7,8,9,10 Divident (@10 MSB), @11 Divisor
				; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	40/8 -> 40 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...255
		; Ergebnis 0...1099511627775
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 892/772/4 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 68 Bytes
	set
	tst @11		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_40x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13
 end:
.endm

.macro div_48x8	; @0,1,2,3,4,5 Ergebnis (@5 MSB), @6 Rest
				; @7,8,9,10,11,12 Divident (@12 MSB), @13 Divisor
				; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	48/8 -> 48 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...255
		; Ergebnis 0...281474976710655
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 1165/1021/4 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 74 Bytes
	set
	tst @13		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_48x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15
 end:
.endm

.macro div_56x8	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), @7 Rest
				; @8,9,10,11,12,13,14 Divident (@14 MSB), @15 Divisor
				; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	56/8 -> 56 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...255
		; Ergebnis 0...72057594037927935
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 1470/1302/4 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 80 Bytes
	set
	tst @15		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_56x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17
 end:
.endm

.macro div_64x8	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), @8 Rest
				; @9,10,11,12,13,14,15,16 Divident (@16 MSB), @17 Divisor
				; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	64/8 -> 64 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...255
		; Ergebnis 0...18446744073709551615
		; Rest     0...254
		; T=1 bedeutet Divisor = 0
		; 1807/1615/4 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 86 Bytes
	set
	tst @17		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_64x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19
 end:
.endm

.macro div_16x16	; @0,1 Ergebnis (@1 MSB), @2,3 Rest (@3 MSB), 
					; @4,5 Divident (@5 MSB), @6,7 Divisor (@7 MSB)
					; @8 Rest-Erweiterung, @9 Null-Register
		; Division 	16/16 -> 16 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...65535
		; Divisor  1...65535
		; Ergebnis 0...65535
		; Rest     0...65534
		; T=1 bedeutet Divisor = 0
		; 315/251/5 Cycles (Divident=65535 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 60 Bytes
	set
	mov @9,@6		; Pruefung Divisor = 0?
	or @9,@7
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_16x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9
 end:
.endm

.macro div_24x16	; @0,1,2 Ergebnis (@2 MSB), @3,4 Rest (@4 MSB), 
					; @5,6,7 Divident (@7 MSB), @8,9 Divisor (@9 MSB)
					; @10 Rest-Erweiterung, @11 Null-Register
		; Division 	24/16 -> 24 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...16777215
		; Divisor  1...65535
		; Ergebnis 0...16777215
		; Rest     0...65534
		; T=1 bedeutet Divisor = 0
		; 516/420/5 Cycles (Divident=16777215 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 66 Bytes
	set
	mov @11,@8		; Pruefung Divisor = 0?
	or @11,@9
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_24x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11
 end:
.endm

.macro div_32x16	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5 Rest (@5 MSB), 
					; @6,7,8,9 Divident (@9 MSB), 
					; @10,11 Divisor (@11 MSB)
					; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	32/16 -> 32 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...65535
		; Ergebnis 0...4294967295
		; Rest     0...65534
		; T=1 bedeutet Divisor = 0
		; 749/621/5 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 72 Bytes
	set
	mov @13,@10		; Pruefung Divisor = 0?
	or @13,@11
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_32x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13
 end:
.endm

.macro div_40x16	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6 Rest (@6 MSB), 
					; @7,8,9,10,11 Divident (@11 MSB), 
					; @12,13 Divisor (@13 MSB)
					; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	40/16 -> 40 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...65535
		; Ergebnis 0...1099511627775
		; Rest     0...65534
		; T=1 bedeutet Divisor = 0
		; 1014/854/5 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 78 Bytes
	set
	mov @15,@12		; Pruefung Divisor = 0?
	or @15,@13
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_40x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15
 end:
.endm

.macro div_48x16	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7 Rest (@7 MSB), 
					; @8,9,10,11,12,13 Divident (@13 MSB), 
					; @14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	48/16 -> 48 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...65535
		; Ergebnis 0...281474976710655
		; Rest     0...65534
		; T=1 bedeutet Divisor = 0
		; 1311/1119/5 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 84 Bytes
	set
	mov @17,@14		; Pruefung Divisor = 0?
	or @17,@15
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_48x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17
 end:
.endm

.macro div_56x16	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8 Rest (@8 MSB), 
					; @9,10,11,12,13,14,15 Divident (@15 MSB), 
					; @16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	56/16 -> 56 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...65535
		; Ergebnis 0...72057594037927935
		; Rest     0...65534
		; T=1 bedeutet Divisor = 0
		; 1640/1416/5 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 90 Bytes
	set
	mov @19,@16		; Pruefung Divisor = 0?
	or @19,@17
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_56x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19
 end:
.endm

.macro div_64x16	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	64/16 -> 64 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...65535
		; Ergebnis 0...18446744073709551615
		; Rest     0...65534
		; T=1 bedeutet Divisor = 0
		; 2001/1745/5 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 96 Bytes
	set
	mov @21,@18		; Pruefung Divisor = 0?
	or @21,@19
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_64x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21
 end:
.endm

.macro div_24x24	; @0,1,2 Ergebnis (@2 MSB), 
					; @3,4,5 Rest (@5 MSB), 
					; @6,7,8 Divident (@8 MSB), 
					; @9,10,11 Divisor (@11 MSB)
					; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	24/24 -> 24 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...16777215
		; Divisor  1...16777215
		; Ergebnis 0...16777215
		; Rest     0...16777214
		; T=1 bedeutet Divisor = 0
		; 590/470/6 Cycles (Divident=16777215 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 76 Bytes
	set
	mov @13,@9		; Pruefung Divisor = 0?
	or @13,@10
	or @13,@11
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_24x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13
 end:
.endm

.macro div_32x24	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5,6 Rest (@6 MSB), 
					; @7,8,9,10 Divident (@10 MSB), 
					; @11,12,13 Divisor (@13 MSB)
					; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	32/24 -> 32 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...16777215
		; Ergebnis 0...4294967295
		; Rest     0...16777214
		; T=1 bedeutet Divisor = 0
		; 847/687/6 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 82 Bytes
	set
	mov @15,@11		; Pruefung Divisor = 0?
	or @15,@12
	or @15,@13
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_32x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15
 end:
.endm

.macro div_40x24	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7 Rest (@7 MSB), 
					; @8,9,10,11,12 Divident (@12 MSB), 
					; @13,14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	40/24 -> 40 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...16777215
		; Ergebnis 0...1099511627775
		; Rest     0...16777214
		; T=1 bedeutet Divisor = 0
		; 1136/936/6 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 88 Bytes
	set
	mov @17,@13		; Pruefung Divisor = 0?
	or @17,@14
	or @17,@15
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_40x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17
 end:
.endm

.macro div_48x24	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8 Rest (@8 MSB), 
					; @9,10,11,12,13,14 Divident (@14 MSB), 
					; @15,16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	48/24 -> 48 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...16777215
		; Ergebnis 0...281474976710655
		; Rest     0...16777214
		; T=1 bedeutet Divisor = 0
		; 1457/1217/6 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 94 Bytes
	set
	mov @19,@15		; Pruefung Divisor = 0?
	or @19,@16
	or @19,@17
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_48x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19
 end:
.endm

.macro div_56x24	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15,16 Divident (@16 MSB), 
					; @17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	56/24 -> 56 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...16777215
		; Ergebnis 0...72057594037927935
		; Rest     0...16777214
		; T=1 bedeutet Divisor = 0
		; 1810/1530/6 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 100 Bytes
	set
	mov @21,@17		; Pruefung Divisor = 0?
	or @21,@18
	or @21,@19
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_56x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21
 end:
.endm

.macro div_64x24	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10 Rest (@10 MSB), 
					; @11,12,13,14,15,16,17,18 Divident (@18 MSB), 
					; @19,20,21 Divisor (@21 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	64/24 -> 64 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...16777215
		; Ergebnis 0...18446744073709551615
		; Rest     0...16777214
		; T=1 bedeutet Divisor = 0
		; 2195/1875/6 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 106 Bytes
	set
	mov @23,@19		; Pruefung Divisor = 0?
	or @23,@20
	or @23,@21
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_64x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23
 end:
.endm

.macro div_32x32	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5,6,7 Rest (@7 MSB), 
					; @8,9,10,11 Divident (@11 MSB), 
					; @12,13,14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	32/32 -> 32 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...4294967295
		; Ergebnis 0...4294967295
		; Rest     0...4294967294
		; T=1 bedeutet Divisor = 0
		; 945/753/7 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 92 Bytes
	set
	mov @17,@12		; Pruefung Divisor = 0?
	or @17,@13
	or @17,@14
	or @17,@15
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_32x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17
 end:
.endm

.macro div_40x32	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7,8 Rest (@8 MSB), 
					; @9,10,11,12,13 Divident (@13 MSB), 
					; @14,15,16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	40/32 -> 40 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...4294967295
		; Ergebnis 0...1099511627775
		; Rest     0...4294967294
		; T=1 bedeutet Divisor = 0
		; 1258/1018/7 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 98 Bytes
	set
	mov @19,@14		; Pruefung Divisor = 0?
	or @19,@15
	or @19,@16
	or @19,@17
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_40x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19
 end:
.endm

.macro div_48x32	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15 Divident (@15 MSB), 
					; @16,17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	48/32 -> 48 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...4294967295
		; Ergebnis 0...281474976710655
		; Rest     0...4294967294
		; T=1 bedeutet Divisor = 0
		; 1603/1315/7 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 104 Bytes
	set
	mov @21,@16		; Pruefung Divisor = 0?
	or @21,@17
	or @21,@18
	or @21,@19
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_48x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21
 end:
.endm

.macro div_56x32	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10 Rest (@10 MSB), 
					; @11,12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19,20,21 Divisor (@21 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	56/32 -> 56 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...4294967295
		; Ergebnis 0...72057594037927935
		; Rest     0...4294967294
		; T=1 bedeutet Divisor = 0
		; 1980/1644/7 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 110 Bytes
	set
	mov @23,@18		; Pruefung Divisor = 0?
	or @23,@19
	or @23,@20
	or @23,@21
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_56x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23
 end:
.endm

.macro div_64x32	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17,18,19 Divident (@19 MSB), 
					; @20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	64/32 -> 64 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...4294967295
		; Ergebnis 0...18446744073709551615
		; Rest     0...4294967294
		; T=1 bedeutet Divisor = 0
		; 2389/2005/7 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 116 Bytes
	set
	mov @25,@20		; Pruefung Divisor = 0?
	or @25,@21
	or @25,@22
	or @25,@23
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_64x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25
 end:
.endm

.macro div_40x40	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14 Divident (@14 MSB), 
					; @15,16,17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	40/40 -> 40 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...1099511627775
		; Ergebnis 0...1099511627775
		; Rest     0...1099511627774
		; T=1 bedeutet Divisor = 0
		; 1380/1100/8 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 108 Bytes
	set
	mov @21,@15		; Pruefung Divisor = 0?
	or @21,@16
	or @21,@17
	or @21,@18
	or @21,@19
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_40x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21
 end:
.endm

.macro div_48x40	; @0,1,2,3,4,5 Ergebnis (@0 MSB), 
					; @6,7,8,9,10 Rest (@6 MSB), 
					; @11,12,13,14,15,16 Divident (@11 MSB), 
					; @17,18,19,20,21 Divisor (@17 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	48/40 -> 48 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...1099511627775
		; Ergebnis 0...281474976710655
		; Rest     0...1099511627774
		; T=1 bedeutet Divisor = 0
		; 1749/1413/8 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 114 Bytes
	set
	mov @23,@17		; Pruefung Divisor = 0?
	or @23,@18
	or @23,@19
	or @23,@20
	or @23,@21
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_48x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23
 end:
.endm

.macro div_56x40	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17,18 Divident (@18 MSB), 
					; @19,20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	56/40 -> 56 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...1099511627775
		; Ergebnis 0...72057594037927935
		; Rest     0...1099511627774
		; T=1 bedeutet Divisor = 0
		; 2150/1758/8 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 120 Bytes
	set
	mov @25,@19		; Pruefung Divisor = 0?
	or @25,@20
	or @25,@21
	or @25,@22
	or @25,@23
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_56x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25
 end:
.endm

.macro div_64x40	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12 Rest (@12 MSB), 
					; @13,14,15,16,17,18,19,20 Divident (@20 MSB), 
					; @21,22,23,24,25 Divisor (@25 MSB)
					; @26 Rest-Erweiterung, @27 Null-Register
		; Division 	64/40 -> 64 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...1099511627775
		; Ergebnis 0...18446744073709551615
		; Rest     0...1099511627774
		; T=1 bedeutet Divisor = 0
		; 2583/2135/8 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 126 Bytes
	set
	mov @27,@21		; Pruefung Divisor = 0?
	or @27,@22
	or @27,@23
	or @27,@24
	or @27,@25
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_64x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27
 end:
.endm

.macro div_48x48	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19,20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	48/48 -> 48 bit, Rest 48 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...281474976710655
		; Ergebnis 0...281474976710655
		; Rest     0...281474976710654
		; T=1 bedeutet Divisor = 0
		; 1895/1511/9 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 124 Bytes
	set
	mov @25,@18		; Pruefung Divisor = 0?
	or @25,@19
	or @25,@20
	or @25,@21
	or @25,@22
	or @25,@23
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_48x48__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25
 end:
.endm

.macro div_56x48	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11,12 Rest (@12 MSB), 
					; @13,14,15,16,17,18,19 Divident (@19 MSB), 
					; @20,21,22,23,24,25 Divisor (@25 MSB)
					; @26 Rest-Erweiterung, @27 Null-Register
		; Division 	56/48 -> 56 bit, Rest 48 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...281474976710655
		; Ergebnis 0...72057594037927935
		; Rest     0...281474976710654
		; T=1 bedeutet Divisor = 0
		; 2320/1872/9 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 130 Bytes
	set
	mov @27,@20		; Pruefung Divisor = 0?
	or @27,@21
	or @27,@22
	or @27,@23
	or @27,@24
	or @27,@25
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_56x48__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27
 end:
.endm

.macro div_64x48	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13 Rest (@13 MSB), 
					; @14,15,16,17,18,19,20,21 Divident (@21 MSB), 
					; @22,23,24,25,26,27 Divisor (@27 MSB)
					; @28 Rest-Erweiterung, @29 Null-Register
		; Division 	64/48 -> 64 bit, Rest 48 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...281474976710655
		; Ergebnis 0...18446744073709551615
		; Rest     0...281474976710654
		; T=1 bedeutet Divisor = 0
		; 2777/2265/9 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 136 Bytes
	set
	mov @29,@22		; Pruefung Divisor = 0?
	or @29,@23
	or @29,@24
	or @29,@25
	or @29,@26
	or @29,@27
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_64x48__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29
 end:
.endm

.macro div_56x56	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11,12,13 Rest (@13 MSB), 
					; @14,15,16,17,18,19,20 Divident (@20 MSB), 
					; @21,22,23,24,25,26,27 Divisor (@27 MSB)
					; @28 Rest-Erweiterung, @29 Null-Register
		; Division 	56/56 -> 56 bit, Rest 56 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...72057594037927935
		; Ergebnis 0...72057594037927935
		; Rest     0...72057594037927934
		; T=1 bedeutet Divisor = 0
		; 2490/1986/10 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 140 Bytes
	set
	mov @29,@21		; Pruefung Divisor = 0?
	or @29,@22
	or @29,@23
	or @29,@24
	or @29,@25
	or @29,@26
	or @29,@27
	breq end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_56x56__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29
 end:
.endm

.macro div_64x56	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13,14 Rest (@14 MSB), 
					; @15,16,17,18,19,20,21,22 Divident (@22 MSB), 
					; @23,24,25,26,27,28,29 Divisor (@29 MSB)
					; @30 Rest-Erweiterung, @31 Null-Register
		; Division 	64/56 -> 64 bit, Rest 56 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...72057594037927935
		; Ergebnis 0...18446744073709551615
		; Rest     0...72057594037927934
		; T=1 bedeutet Divisor = 0
		; 2972/2396/11 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 148 Bytes
	set
	mov @31,@23		; Pruefung Divisor = 0?
	or @31,@24
	or @31,@25
	or @31,@26
	or @31,@27
	or @31,@28
	or @31,@29
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	clt
	div_64x56__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29,@30,@31
 end:
.endm

.macro div_64x64	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13,14,15 Rest (@15 MSB), 
					; @16,17,18,19,20,21,22,23 Divident (@23 MSB), 
					; @24,25,26,27,28,29,30,31 Divisor (@31 MSB)
					; @29 Divisor-Puffer
					; @30 Rest-Erweiterung
					; @31 Null-Register
					; @32 Ram-Puffer-24 fuer Divisor (3 Bytes in SRAM)
		; Division 	64/64 -> 64 bit, Rest 64 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...18446744073709551615
		; Ergebnis 0...18446744073709551615
		; Rest     0...18446744073709551614
		; T=1 bedeutet Divisor = 0
		; 3940/2916/12 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 194 Bytes
	set
	mov @15,@24		; Pruefung Divisor = 0?
	or @15,@25
	or @15,@26
	or @15,@27
	or @15,@28
	or @15,@29
	or @15,@30
	or @15,@31
	brne PC+2
	rjmp end
	clt
	div_64x64__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29,@30,@31,@32
 end:
.endm

;=================================================================================
;=== div signed ==================================================================
;=================================================================================
.macro div_8x8_s	; @0 Ergebnis, @1 Rest, @2 Divident, @3 Divisor
		; Division 	8/8 -> 8 bit, Rest 8 bit (signed / signed)
		; Divident -128...127
		; Divisor  -128...-1, 1...127
		; Ergebnis -128...128
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 101/87/4 Cycles (Divident=127 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 60 Bytes
	set
	tst @3		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1

	clr @0	; tmp-reg
	tst @2	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg @2	; wenn Minus, Neg
 mn1:
 	tst @3	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @3	; wenn Minus, Neg
 mn2:
 	bst	@0,0	; wenn T=1, Ergebnis und Rest NEG

	div_8x8__ @0,@1,@2,@3

	brtc end	; wenn T=1
	neg @0		; Ergebnis NEG
	neg @1		; Rest NEG
	clt
 end:
.endm

.macro div_16x8_s	; @0,1 Ergebnis (@1 MSB), @2 Rest
				; @3,4 Divident (@4 MSB), @5 Divisor
				; @6 Rest-Erweiterung, @7 Null-Register
		; Division 	16/8 -> 16 bit, Rest 8 bit (signed / signed)
		; Divident -32768...32767
		; Divisor  -128...-1, 1...127
		; Ergebnis -32768...32768
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 271/226/4 Cycles (Divident=32767 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 92 Bytes
	set
	tst @5		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @4	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg16 @3,@4,@1	; wenn Minus, Neg
 mn1:
 	tst @5	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @5	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_16x8__ @0,@1,@2,@3,@4,@5,@6,@7

	brtc end		; wenn T=1
	neg16 @0,@1,@7		; Ergebnis NEG
	neg @2			; Rest NEG
	clt
 end:
.endm

.macro div_24x8_s	; @0,1,2 Ergebnis (@2 MSB), @3 Rest
				; @4,5,6 Divident (@6 MSB), @7 Divisor
				; @8 Rest-Erweiterung, @9 Null-Register
		; Division 	24/8 -> 24 bit, Rest 8 bit (signed / signed)
		; Divident -8388608...8388607
		; Divisor  -128...-1, 1...127
		; Ergebnis -8388608...8388608
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 448/379/4 Cycles (Divident=8388607 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 106 Bytes
	set
	tst @7		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @6	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg24 @4,@5,@6,@1	; wenn Minus, Neg
 mn1:
 	tst @7	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @7	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_24x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9

	brtc end		; wenn T=1
	neg24 @0,@1,@2,@9		; Ergebnis NEG
	neg @3			; Rest NEG
	clt
 end:
.endm

.macro div_32x8_s	; @0,1,2,3 Ergebnis (@3 MSB), @4 Rest
				; @5,6,7,8 Divident (@8 MSB), @9 Divisor
				; @10 Rest-Erweiterung, @11 Null-Register
		; Division 	32/8 -> 32 bit, Rest 8 bit (signed / signed)
		; Divident -2147483648...2147483647
		; Divisor  -128...-1, 1...127
		; Ergebnis -2147483648...2147483648
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 657/564/4 Cycles (Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 120 Bytes
	set
	tst @9		; Pruefung Divisor = 0?
	breq end	; wenn Divisor = 0, Schluss mit T=1

	clr @0	; tmp-reg
	tst @8	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg32 @5,@6,@7,@8,@1	; wenn Minus, Neg
 mn1:
 	tst @9	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @9	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_32x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11

	brtc end		; wenn T=1
	neg32 @0,@1,@2,@3,@11	; Ergebnis NEG
	neg @4			; Rest NEG
	clt
 end:
.endm

.macro div_40x8_s	; @0,1,2,3,4 Ergebnis (@4 MSB), @5 Rest
				; @6,7,8,9,10 Divident (@10 MSB), @11 Divisor
				; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	40/8 -> 40 bit, Rest 8 bit (signed / signed)
		; Divident -549755813888...549755813887
		; Divisor  -128...-1, 1...127
		; Ergebnis -549755813888...549755813888
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 899/782/5 Cycles (Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 136 Bytes
	set
	tst @11		; Pruefung Divisor = 0?
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @10	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg40 @6,@7,@8,@9,@10,@1	; wenn Minus, Neg
 mn1:
 	tst @11	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @11	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_40x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13

	brtc end		; wenn T=1
	neg40 @0,@1,@2,@3,@4,@13	; Ergebnis NEG
	neg @5			; Rest NEG
	clt
 end:
.endm

.macro div_48x8_s	; @0,1,2,3,4,5 Ergebnis (@5 MSB), @6 Rest
				; @7,8,9,10,11,12 Divident (@12 MSB), @13 Divisor
				; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	48/8 -> 48 bit, Rest 8 bit (signed / signed)
		; Divident -140737488355328...140737488355327
		; Divisor  -128...-1, 1...127
		; Ergebnis -140737488355328...140737488355328
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 1172/1031/5 Cycles (Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 150 Bytes
	set
	tst @13		; Pruefung Divisor = 0?
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @12	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg48 @7,@8,@9,@10,@11,@12,@1	; wenn Minus, Neg
 mn1:
 	tst @13	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @13	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_48x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15

	brtc end		; wenn T=1
	neg48 @0,@1,@2,@3,@4,@5,@15	; Ergebnis NEG
	neg @6			; Rest NEG
	clt
 end:
.endm

.macro div_56x8_s	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), @7 Rest
				; @8,9,10,11,12,13,14 Divident (@14 MSB), @15 Divisor
				; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	56/8 -> 56 bit, Rest 8 bit (signed / signed)
		; Divident -36028797018963968...36028797018963967
		; Divisor  -128...-1, 1...127
		; Ergebnis -36028797018963968...36028797018963968
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 1477/1312/5 Cycles (Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 164 Bytes
	set
	tst @15		; Pruefung Divisor = 0?
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @14	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg56 @8,@9,@10,@11,@12,@13,@14,@1	; wenn Minus, Neg
 mn1:
 	tst @15	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @15	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_56x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17

	brtc end		; wenn T=1
	neg56 @0,@1,@2,@3,@4,@5,@6,@17	; Ergebnis NEG
	neg @7			; Rest NEG
	clt
 end:
.endm

.macro div_64x8_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), @8 Rest
				; @9,10,11,12,13,14,15,16 Divident (@16 MSB), @17 Divisor
				; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	64/8 -> 64 bit, Rest 8 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -128...-1, 1...127
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -127...127
		; T=1 bedeutet Divisor = 0
		; 1814/1625/5 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 178 Bytes
	set
	tst @17		; Pruefung Divisor = 0?
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @16	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @9,@10,@11,@12,@13,@14,@15,@16,@1	; wenn Minus, Neg
 mn1:
 	tst @17	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg @17	; wenn Minus, Neg
 mn2:
 	bst	@0,0
	
	div_64x8__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@19	; Ergebnis NEG
	neg @8			; Rest NEG
	clt
 end:
.endm

.macro div_16x16_s	; @0,1 Ergebnis (@1 MSB), @2,3 Rest (@3 MSB), 
					; @4,5 Divident (@5 MSB), @6,7 Divisor (@7 MSB)
					; @8 Rest-Erweiterung, @9 Null-Register
		; Division 	16/16 -> 16 bit, Rest 16 bit (signed / signed)
		; Divident -32768...32767
		; Divisor  -32768...-1, 1...32767
		; Ergebnis -32768...32768
		; Rest     -32767...32767
		; T=1 bedeutet Divisor = 0
		; 320/260/5 Cycles (Divident=32767 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 118 Bytes
	set
	mov @9,@6		; Pruefung Divisor = 0?
	or @9,@7
	breq end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @5	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg16 @4,@5,@1	; wenn Minus, Neg
 mn1:
 	tst @7	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg16 @6,@7,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_16x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9

	brtc end		; wenn T=1
	neg16 @0,@1,@9	; Ergebnis NEG
	neg16 @2,@3,@9	; Rest NEG
	clt
 end:
.endm

.macro div_24x16_s	; @0,1,2 Ergebnis (@2 MSB), @3,4 Rest (@4 MSB), 
					; @5,6,7 Divident (@7 MSB), @8,9 Divisor (@9 MSB)
					; @10 Rest-Erweiterung, @11 Null-Register
		; Division 	24/16 -> 24 bit, Rest 16 bit (signed / signed)
		; Divident -8388608...8388607
		; Divisor  -32768...-1, 1...32767
		; Ergebnis -8388608...8388608
		; Rest     -32767...32767
		; T=1 bedeutet Divisor = 0
		; 521/429/5 Cycles (Divident=8388607 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 132 Bytes
	set
	mov @11,@8		; Pruefung Divisor = 0?
	or @11,@9
	breq end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @7	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg24 @5,@6,@7,@1	; wenn Minus, Neg
 mn1:
 	tst @9	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg16 @8,@9,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_24x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11

	brtc end		; wenn T=1
	neg24 @0,@1,@2,@11	; Ergebnis NEG
	neg16 @3,@4,@11	; Rest NEG
	clt
 end:
.endm

.macro div_32x16_s	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5 Rest (@5 MSB), 
					; @6,7,8,9 Divident (@9 MSB), 
					; @10,11 Divisor (@11 MSB)
					; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	32/16 -> 32 bit, Rest 16 bit (signed / signed)
		; Divident -2147483648...2147483647
		; Divisor  -32768...-1, 1...32767
		; Ergebnis -2147483648...2147483648
		; Rest     -32767...32767
		; T=1 bedeutet Divisor = 0
		; 755/631/6 Cycles (Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 148 Bytes
	set
	mov @13,@10		; Pruefung Divisor = 0?
	or @13,@11
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @9	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg32 @6,@7,@8,@9,@1	; wenn Minus, Neg
 mn1:
 	tst @11	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg16 @10,@11,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_32x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13

	brtc end		; wenn T=1
	neg32 @0,@1,@2,@3,@13	; Ergebnis NEG
	neg16 @4,@5,@13	; Rest NEG
	clt
 end:
.endm

.macro div_40x16_s	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6 Rest (@6 MSB), 
					; @7,8,9,10,11 Divident (@11 MSB), 
					; @12,13 Divisor (@13 MSB)
					; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	40/16 -> 40 bit, Rest 16 bit (signed / signed)
		; Divident -549755813888...549755813887
		; Divisor  -32768...-1, 1...32767
		; Ergebnis -549755813888...549755813888
		; Rest     -32767...32767
		; T=1 bedeutet Divisor = 0
		; 1020/864/6 Cycles (Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 162 Bytes
	set
	mov @15,@12		; Pruefung Divisor = 0?
	or @15,@13
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @11	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg40 @7,@8,@9,@10,@11,@1	; wenn Minus, Neg
 mn1:
 	tst @13	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg16 @12,@13,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_40x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15

	brtc end		; wenn T=1
	neg40 @0,@1,@2,@3,@4,@15	; Ergebnis NEG
	neg16 @5,@6,@15	; Rest NEG
	clt
 end:
.endm

.macro div_48x16_s	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7 Rest (@7 MSB), 
					; @8,9,10,11,12,13 Divident (@13 MSB), 
					; @14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	48/16 -> 48 bit, Rest 16 bit (signed / signed)
		; Divident -140737488355328...140737488355327
		; Divisor  -32768...-1, 1...32767
		; Ergebnis -140737488355328...140737488355328
		; Rest     -32767...32767
		; T=1 bedeutet Divisor = 0
		; 1317/1129/6 Cycles (Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 176 Bytes
	set
	mov @17,@14		; Pruefung Divisor = 0?
	or @17,@15
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @13	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg48 @8,@9,@10,@11,@12,@13,@1	; wenn Minus, Neg
 mn1:
 	tst @15	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg16 @14,@15,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_48x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17

	brtc end		; wenn T=1
	neg48 @0,@1,@2,@3,@4,@5,@17	; Ergebnis NEG
	neg16 @6,@7,@17	; Rest NEG
	clt
 end:
.endm

.macro div_56x16_s	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8 Rest (@8 MSB), 
					; @9,10,11,12,13,14,15 Divident (@15 MSB), 
					; @16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	56/16 -> 56 bit, Rest 16 bit (signed / signed)
		; Divident -36028797018963968...36028797018963967
		; Divisor  -32768...-1, 1...32767
		; Ergebnis -36028797018963968...36028797018963968
		; Rest     -32767...32767
		; T=1 bedeutet Divisor = 0
		; 1646/1426/6 Cycles (Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 190 Bytes
	set
	mov @19,@16		; Pruefung Divisor = 0?
	or @19,@17
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @15	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg56 @9,@10,@11,@12,@13,@14,@15,@1	; wenn Minus, Neg
 mn1:
 	tst @17	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg16 @16,@17,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_56x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19

	brtc end		; wenn T=1
	neg56 @0,@1,@2,@3,@4,@5,@6,@19	; Ergebnis NEG
	neg16 @7,@8,@19	; Rest NEG
	clt
 end:
.endm

.macro div_64x16_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	64/16 -> 64 bit, Rest 16 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -32768...-1, 1...32767
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -32767...32767
		; T=1 bedeutet Divisor = 0
		; 2007/1755/6 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 204 Bytes
	set
	mov @21,@18		; Pruefung Divisor = 0?
	or @21,@19
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @17	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @10,@11,@12,@13,@14,@15,@16,@17,@1	; wenn Minus, Neg
 mn1:
 	tst @19	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg16 @18,@19,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_64x16__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@21	; Ergebnis NEG
	neg16 @8,@9,@21	; Rest NEG
	clt
 end:
.endm

.macro div_24x24_s	; @0,1,2 Ergebnis (@2 MSB), 
					; @3,4,5 Rest (@5 MSB), 
					; @6,7,8 Divident (@8 MSB), 
					; @9,10,11 Divisor (@11 MSB)
					; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	24/24 -> 24 bit, Rest 24 bit (signed / signed)
		; Divident -8388608...8388607
		; Divisor  -8388608...-1, 1...8388607
		; Ergebnis -8388608...8388608
		; Rest     -8388607...8388607
		; T=1 bedeutet Divisor = 0
		; 595/480/7 Cycles (Divident=8388607 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 152 Bytes
	set
	mov @13,@9		; Pruefung Divisor = 0?
	or @13,@10
	or @13,@11
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @8	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg24 @6,@7,@8,@1	; wenn Minus, Neg
 mn1:
 	tst @11	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg24 @9,@10,@11,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_24x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13

	brtc end		; wenn T=1
	neg24 @0,@1,@2,@13	; Ergebnis NEG
	neg24 @3,@4,@5,@13	; Rest NEG
	clt
 end:
.endm

.macro div_32x24_s	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5,6 Rest (@6 MSB), 
					; @7,8,9,10 Divident (@10 MSB), 
					; @11,12,13 Divisor (@13 MSB)
					; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	32/24 -> 32 bit, Rest 24 bit (signed / signed)
		; Divident -2147483648...2147483647
		; Divisor  -8388608...-1, 1...8388607
		; Ergebnis -2147483648...2147483648
		; Rest     -8388607...8388607
		; T=1 bedeutet Divisor = 0
		; 852/697/7 Cycles (Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 166 Bytes
	set
	mov @15,@11		; Pruefung Divisor = 0?
	or @15,@12
	or @15,@13
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @10	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg32 @7,@8,@9,@10,@1	; wenn Minus, Neg
 mn1:
 	tst @13	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg24 @11,@12,@13,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_32x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15

	brtc end		; wenn T=1
	neg32 @0,@1,@2,@3,@15	; Ergebnis NEG
	neg24 @4,@5,@6,@15	; Rest NEG
	clt
 end:
.endm

.macro div_40x24_s	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7 Rest (@7 MSB), 
					; @8,9,10,11,12 Divident (@12 MSB), 
					; @13,14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	40/24 -> 40 bit, Rest 24 bit (signed / signed)
		; Divident -549755813888...549755813887
		; Divisor  -8388608...-1, 1...8388607
		; Ergebnis -549755813888...549755813888
		; Rest     -8388607...8388607
		; T=1 bedeutet Divisor = 0
		; 1141/946/7 Cycles (Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 180 Bytes
	set
	mov @17,@13		; Pruefung Divisor = 0?
	or @17,@14
	or @17,@15
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @12	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg40 @8,@9,@10,@11,@12,@1	; wenn Minus, Neg
 mn1:
 	tst @15	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg24 @13,@14,@15,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_40x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17

	brtc end		; wenn T=1
	neg40 @0,@1,@2,@3,@4,@17	; Ergebnis NEG
	neg24 @5,@6,@7,@17	; Rest NEG
	clt
 end:
.endm

.macro div_48x24_s	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8 Rest (@8 MSB), 
					; @9,10,11,12,13,14 Divident (@14 MSB), 
					; @15,16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	48/24 -> 48 bit, Rest 24 bit (signed / signed)
		; Divident -140737488355328...140737488355327
		; Divisor  -8388608...-1, 1...8388607
		; Ergebnis -140737488355328...140737488355328
		; Rest     -8388607...8388607
		; T=1 bedeutet Divisor = 0
		; 1462/1227/7 Cycles (Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 194 Bytes
	set
	mov @19,@15		; Pruefung Divisor = 0?
	or @19,@16
	or @19,@17
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @14	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg48 @9,@10,@11,@12,@13,@14,@1	; wenn Minus, Neg
 mn1:
 	tst @17	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg24 @15,@16,@17,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_48x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19

	brtc end		; wenn T=1
	neg48 @0,@1,@2,@3,@4,@5,@19	; Ergebnis NEG
	neg24 @6,@7,@8,@19	; Rest NEG
	clt
 end:
.endm

.macro div_56x24_s	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15,16 Divident (@16 MSB), 
					; @17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	56/24 -> 56 bit, Rest 24 bit (signed / signed)
		; Divident -36028797018963968...36028797018963967
		; Divisor  -8388608...-1, 1...8388607
		; Ergebnis -36028797018963968...36028797018963968
		; Rest     -8388607...8388607
		; T=1 bedeutet Divisor = 0
		; 1815/1540/7 Cycles (Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 208 Bytes
	set
	mov @21,@17		; Pruefung Divisor = 0?
	or @21,@18
	or @21,@19
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @16	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg56 @10,@11,@12,@13,@14,@15,@16,@1	; wenn Minus, Neg
 mn1:
 	tst @19	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg24 @17,@18,@19,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_56x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21

	brtc end		; wenn T=1
	neg56 @0,@1,@2,@3,@4,@5,@6,@21	; Ergebnis NEG
	neg24 @7,@8,@9,@21	; Rest NEG
	clt
 end:
.endm

.macro div_64x24_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10 Rest (@10 MSB), 
					; @11,12,13,14,15,16,17,18 Divident (@18 MSB), 
					; @19,20,21 Divisor (@21 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	64/24 -> 64 bit, Rest 24 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -8388608...-1, 1...8388607
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -8388607...8388607
		; T=1 bedeutet Divisor = 0
		; 2200/1885/7 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 222 Bytes
	set
	mov @23,@19		; Pruefung Divisor = 0?
	or @23,@20
	or @23,@21
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @18	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @11,@12,@13,@14,@15,@16,@17,@18,@1	; wenn Minus, Neg
 mn1:
 	tst @21	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg24 @19,@20,@21,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_64x24__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@23	; Ergebnis NEG
	neg24 @8,@9,@10,@23	; Rest NEG
	clt
 end:
.endm

.macro div_32x32_s	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5,6,7 Rest (@7 MSB), 
					; @8,9,10,11 Divident (@11 MSB), 
					; @12,13,14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	32/32 -> 32 bit, Rest 32 bit (signed / signed)
		; Divident -2147483648...2147483647
		; Divisor  -2147483648...-1, 1...2147483647
		; Ergebnis -2147483648...2147483648
		; Rest     -2147483647...2147483647
		; T=1 bedeutet Divisor = 0
		; 949/763/8 Cycles (Divident=2147483647 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 184 Bytes
	set
	mov @17,@12		; Pruefung Divisor = 0?
	or @17,@13
	or @17,@14
	or @17,@15
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @11	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg32 @8,@9,@10,@11,@1	; wenn Minus, Neg
 mn1:
 	tst @15	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg32 @12,@13,@14,@15,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_32x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17

	brtc end		; wenn T=1
	neg32 @0,@1,@2,@3,@17	; Ergebnis NEG
	neg32 @4,@5,@6,@7,@17	; Rest NEG
	clt
 end:
.endm

.macro div_40x32_s	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7,8 Rest (@8 MSB), 
					; @9,10,11,12,13 Divident (@13 MSB), 
					; @14,15,16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	40/32 -> 40 bit, Rest 32 bit (signed / signed)
		; Divident -549755813888...549755813887
		; Divisor  -2147483648...-1, 1...2147483647
		; Ergebnis -549755813888...549755813888
		; Rest     -2147483647...2147483647
		; T=1 bedeutet Divisor = 0
		; 1262/1028/8 Cycles (Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 198 Bytes
	set
	mov @19,@14		; Pruefung Divisor = 0?
	or @19,@15
	or @19,@16
	or @19,@17
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @13	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg40 @9,@10,@11,@12,@13,@1	; wenn Minus, Neg
 mn1:
 	tst @17	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg32 @14,@15,@16,@17,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_40x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19

	brtc end		; wenn T=1
	neg40 @0,@1,@2,@3,@4,@19	; Ergebnis NEG
	neg32 @5,@6,@7,@8,@19	; Rest NEG
	clt
 end:
.endm

.macro div_48x32_s	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15 Divident (@15 MSB), 
					; @16,17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	48/32 -> 48 bit, Rest 32 bit (signed / signed)
		; Divident -140737488355328...140737488355327
		; Divisor  -2147483648...-1, 1...2147483647
		; Ergebnis -140737488355328...140737488355328
		; Rest     -2147483647...2147483647
		; T=1 bedeutet Divisor = 0
		; 1607/1325/8 Cycles (Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 212 Bytes
	set
	mov @21,@16		; Pruefung Divisor = 0?
	or @21,@17
	or @21,@18
	or @21,@19
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @15	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg48 @10,@11,@12,@13,@14,@15,@1	; wenn Minus, Neg
 mn1:
 	tst @19	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg32 @16,@17,@18,@19,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_48x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21

	brtc end		; wenn T=1
	neg48 @0,@1,@2,@3,@4,@5,@21	; Ergebnis NEG
	neg32 @6,@7,@8,@9,@21	; Rest NEG
	clt
 end:
.endm

.macro div_56x32_s	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10 Rest (@10 MSB), 
					; @11,12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19,20,21 Divisor (@21 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	56/32 -> 56 bit, Rest 32 bit (signed / signed)
		; Divident -36028797018963968...36028797018963967
		; Divisor  -2147483648...-1, 1...2147483647
		; Ergebnis -36028797018963968...36028797018963968
		; Rest     -2147483647...2147483647
		; T=1 bedeutet Divisor = 0
		; 1984/1654/8 Cycles (Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 226 Bytes
	set
	mov @23,@18		; Pruefung Divisor = 0?
	or @23,@19
	or @23,@20
	or @23,@21
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @17	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg56 @11,@12,@13,@14,@15,@16,@17,@1	; wenn Minus, Neg
 mn1:
 	tst @21	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg32 @18,@19,@20,@21,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_56x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23

	brtc end		; wenn T=1
	neg56 @0,@1,@2,@3,@4,@5,@6,@23	; Ergebnis NEG
	neg32 @7,@8,@9,@10,@23	; Rest NEG
	clt
 end:
.endm

.macro div_64x32_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17,18,19 Divident (@19 MSB), 
					; @20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	64/32 -> 64 bit, Rest 32 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -2147483648...-1, 1...2147483647
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -2147483647...2147483647
		; T=1 bedeutet Divisor = 0
		; 2393/2015/8 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 240 Bytes
	set
	mov @25,@20		; Pruefung Divisor = 0?
	or @25,@21
	or @25,@22
	or @25,@23
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @19	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @12,@13,@14,@15,@16,@17,@18,@19,@1	; wenn Minus, Neg
 mn1:
 	tst @23	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg32 @20,@21,@22,@23,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_64x32__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@25	; Ergebnis NEG
	neg32 @8,@9,@10,@11,@25	; Rest NEG
	clt
 end:
.endm

.macro div_40x40_s	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14 Divident (@14 MSB), 
					; @15,16,17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	40/40 -> 40 bit, Rest 40 bit (signed / signed)
		; Divident -549755813888...549755813887
		; Divisor  -549755813888...-1, 1...549755813887
		; Ergebnis -549755813888...549755813888
		; Rest     -549755813887...549755813887
		; T=1 bedeutet Divisor = 0
		; 1383/1110/9 Cycles (Divident=549755813887 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 216 Bytes
	set
	mov @21,@15		; Pruefung Divisor = 0?
	or @21,@16
	or @21,@17
	or @21,@18
	or @21,@19
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @14	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg40 @10,@11,@12,@13,@14,@1	; wenn Minus, Neg
 mn1:
 	tst @19	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg40 @15,@16,@17,@18,@19,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_40x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21

	brtc end		; wenn T=1
	neg40 @0,@1,@2,@3,@4,@21	; Ergebnis NEG
	neg40 @5,@6,@7,@8,@9,@21	; Rest NEG
	clt
 end:
.endm

.macro div_48x40_s	; @0,1,2,3,4,5 Ergebnis (@0 MSB), 
					; @6,7,8,9,10 Rest (@6 MSB), 
					; @11,12,13,14,15,16 Divident (@11 MSB), 
					; @17,18,19,20,21 Divisor (@17 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	48/40 -> 48 bit, Rest 40 bit (signed / signed)
		; Divident -140737488355328...140737488355327
		; Divisor  -549755813888...-1, 1...549755813887
		; Ergebnis -140737488355328...140737488355328
		; Rest     -549755813887...549755813887
		; T=1 bedeutet Divisor = 0
		; 1752/1423/9 Cycles (Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 230 Bytes
	set
	mov @23,@17		; Pruefung Divisor = 0?
	or @23,@18
	or @23,@19
	or @23,@20
	or @23,@21
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @16	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg48 @11,@12,@13,@14,@15,@16,@1	; wenn Minus, Neg
 mn1:
 	tst @21	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg40 @17,@18,@19,@20,@21,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_48x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23

	brtc end		; wenn T=1
	neg48 @0,@1,@2,@3,@4,@5,@23	; Ergebnis NEG
	neg40 @6,@7,@8,@9,@10,@23	; Rest NEG
	clt
 end:
.endm

.macro div_56x40_s	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17,18 Divident (@18 MSB), 
					; @19,20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	56/40 -> 56 bit, Rest 40 bit (signed / signed)
		; Divident -36028797018963968...36028797018963967
		; Divisor  -549755813888...-1, 1...549755813887
		; Ergebnis -36028797018963968...36028797018963968
		; Rest     -549755813887...549755813887
		; T=1 bedeutet Divisor = 0
		; 2153/1768/9 Cycles (Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 244 Bytes
	set
	mov @25,@19		; Pruefung Divisor = 0?
	or @25,@20
	or @25,@21
	or @25,@22
	or @25,@23
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @18	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg56 @12,@13,@14,@15,@16,@17,@18,@1	; wenn Minus, Neg
 mn1:
 	tst @23	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg40 @19,@20,@21,@22,@23,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_56x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25

	brtc end		; wenn T=1
	neg56 @0,@1,@2,@3,@4,@5,@6,@25	; Ergebnis NEG
	neg40 @7,@8,@9,@10,@11,@25	; Rest NEG
	clt
 end:
.endm

.macro div_64x40_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12 Rest (@12 MSB), 
					; @13,14,15,16,17,18,19,20 Divident (@20 MSB), 
					; @21,22,23,24,25 Divisor (@25 MSB)
					; @26 Rest-Erweiterung, @27 Null-Register
		; Division 	64/40 -> 64 bit, Rest 40 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -549755813888...-1, 1...549755813887
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -549755813887...549755813887
		; T=1 bedeutet Divisor = 0
		; 2586/2145/9 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 258 Bytes
	set
	mov @27,@21		; Pruefung Divisor = 0?
	or @27,@22
	or @27,@23
	or @27,@24
	or @27,@25
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @20	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @13,@14,@15,@16,@17,@18,@19,@20,@1	; wenn Minus, Neg
 mn1:
 	tst @25	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg40 @21,@22,@23,@24,@25,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_64x40__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@27	; Ergebnis NEG
	neg40 @8,@9,@10,@11,@12,@27	; Rest NEG
	clt
 end:
.endm

.macro div_48x48_s	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19,20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	48/48 -> 48 bit, Rest 48 bit (signed / signed)
		; Divident -140737488355328...140737488355327
		; Divisor  -140737488355328...-1, 1...140737488355327
		; Ergebnis -140737488355328...140737488355328
		; Rest     -140737488355327...140737488355327
		; T=1 bedeutet Divisor = 0
		; 1897/1521/10 Cycles (Divident=140737488355327 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 248 Bytes
	set
	mov @25,@18		; Pruefung Divisor = 0?
	or @25,@19
	or @25,@20
	or @25,@21
	or @25,@22
	or @25,@23
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @17	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg48 @12,@13,@14,@15,@16,@17,@1	; wenn Minus, Neg
 mn1:
 	tst @23	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg48 @18,@19,@20,@21,@22,@23,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_48x48__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25

	brtc end		; wenn T=1
	neg48 @0,@1,@2,@3,@4,@5,@25	; Ergebnis NEG
	neg48 @6,@7,@8,@9,@10,@11,@25	; Rest NEG
	clt
 end:
.endm

.macro div_56x48_s	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11,12 Rest (@12 MSB), 
					; @13,14,15,16,17,18,19 Divident (@19 MSB), 
					; @20,21,22,23,24,25 Divisor (@25 MSB)
					; @26 Rest-Erweiterung, @27 Null-Register
		; Division 	56/48 -> 56 bit, Rest 48 bit (signed / signed)
		; Divident -36028797018963968...36028797018963967
		; Divisor  -140737488355328...-1, 1...140737488355327
		; Ergebnis -36028797018963968...36028797018963968
		; Rest     -140737488355327...140737488355327
		; T=1 bedeutet Divisor = 0
		; 2322/1882/10 Cycles (Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 262 Bytes
	set
	mov @27,@20		; Pruefung Divisor = 0?
	or @27,@21
	or @27,@22
	or @27,@23
	or @27,@24
	or @27,@25
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @19	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg56 @13,@14,@15,@16,@17,@18,@19,@1	; wenn Minus, Neg
 mn1:
 	tst @25	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg48 @20,@21,@22,@23,@24,@25,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_56x48__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27

	brtc end		; wenn T=1
	neg56 @0,@1,@2,@3,@4,@5,@6,@27	; Ergebnis NEG
	neg48 @7,@8,@9,@10,@11,@12,@27	; Rest NEG
	clt
 end:
.endm

.macro div_64x48_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13 Rest (@13 MSB), 
					; @14,15,16,17,18,19,20,21 Divident (@21 MSB), 
					; @22,23,24,25,26,27 Divisor (@27 MSB)
					; @28 Rest-Erweiterung, @29 Null-Register
		; Division 	64/48 -> 64 bit, Rest 48 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -140737488355328...-1, 1...140737488355327
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -140737488355327...140737488355327
		; T=1 bedeutet Divisor = 0
		; 2779/2275/10 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 276 Bytes
	set
	mov @29,@22		; Pruefung Divisor = 0?
	or @29,@23
	or @29,@24
	or @29,@25
	or @29,@26
	or @29,@27
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @21	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @14,@15,@16,@17,@18,@19,@20,@21,@1	; wenn Minus, Neg
 mn1:
 	tst @27	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg48 @22,@23,@24,@25,@26,@27,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_64x48__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@29	; Ergebnis NEG
	neg48 @8,@9,@10,@11,@12,@13,@29	; Rest NEG
	clt
 end:
.endm

.macro div_56x56_s	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11,12,13 Rest (@13 MSB), 
					; @14,15,16,17,18,19,20 Divident (@20 MSB), 
					; @21,22,23,24,25,26,27 Divisor (@27 MSB)
					; @28 Rest-Erweiterung, @29 Null-Register
		; Division 	56/56 -> 56 bit, Rest 56 bit (signed / signed)
		; Divident -36028797018963968...36028797018963967
		; Divisor  -36028797018963968...-1, 1...36028797018963967
		; Ergebnis -36028797018963968...36028797018963968
		; Rest     -36028797018963967...36028797018963967
		; T=1 bedeutet Divisor = 0
		; 2491/1996/11 Cycles (Divident=36028797018963967 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 280 Bytes
	set
	mov @29,@21		; Pruefung Divisor = 0?
	or @29,@22
	or @29,@23
	or @29,@24
	or @29,@25
	or @29,@26
	or @29,@27
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @20	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg56 @14,@15,@16,@17,@18,@19,@20,@1	; wenn Minus, Neg
 mn1:
 	tst @27	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg56 @21,@22,@23,@24,@25,@26,@27,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_56x56__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29

	brtc end		; wenn T=1
	neg56 @0,@1,@2,@3,@4,@5,@6,@29	; Ergebnis NEG
	neg56 @7,@8,@9,@10,@11,@12,@13,@29	; Rest NEG
	clt
 end:
.endm

.macro div_64x56_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13,14 Rest (@14 MSB), 
					; @15,16,17,18,19,20,21,22 Divident (@22 MSB), 
					; @23,24,25,26,27,28,29 Divisor (@29 MSB)
					; @30 Rest-Erweiterung, @31 Null-Register
		; Division 	64/56 -> 64 bit, Rest 56 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -36028797018963968...-1, 1...36028797018963967
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -36028797018963967...36028797018963967
		; T=1 bedeutet Divisor = 0
		; 2972/2405/11 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 294 Bytes
	set
	mov @31,@23		; Pruefung Divisor = 0?
	or @31,@24
	or @31,@25
	or @31,@26
	or @31,@27
	or @31,@28
	or @31,@29
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @22	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @15,@16,@17,@18,@19,@20,@21,@22,@1	; wenn Minus, Neg
 mn1:
 	tst @29	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg56 @23,@24,@25,@26,@27,@28,@29,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_64x56__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29,@30,@31

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@31	; Ergebnis NEG
	neg56 @8,@9,@10,@11,@12,@13,@14,@31	; Rest NEG
	clt
 end:
.endm

.macro div_64x64_s	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13,14,15 Rest (@15 MSB), 
					; @16,17,18,19,20,21,22,23 Divident (@23 MSB), 
					; @24,25,26,27,28,29,30,31 Divisor (@31 MSB)
					; @29 Divisor-Puffer
					; @30 Rest-Erweiterung
					; @31 Null-Register
					; @32 Ram-Puffer-24 fuer Divisor (3 Bytes in SRAM)
		; Division 	64/64 -> 64 bit, Rest 64 bit (signed / signed)
		; Divident -9223372036854775808...9223372036854775807
		; Divisor  -9223372036854775808...-1, 1...9223372036854775807
		; Ergebnis -9223372036854775808...9223372036854775808
		; Rest     -9223372036854775807...9223372036854775807
		; T=1 bedeutet Divisor = 0
		; 3933/2925/12 Cycles (Divident=9223372036854775807 Divisor=1/Divident=0 Divisor=1/Divisor=0),
		; 348 Bytes
	set
	mov @15,@24		; Pruefung Divisor = 0?
	or @15,@25
	or @15,@26
	or @15,@27
	or @15,@28
	or @15,@29
	or @15,@30
	or @15,@31
	brne PC+2
	rjmp end	; wenn Divisor = 0, Schluss mit T=1
	
	clr @0	; tmp-reg
	tst @23	; Divident auf Minus pruefen
	brpl  mn1
	inc @0
	neg64 @16,@17,@18,@19,@20,@21,@22,@23,@1	; wenn Minus, Neg
 mn1:
 	tst @31	; Divisor auf Minus pruefen
	brpl mn2
	inc @0
	neg64 @24,@25,@26,@27,@28,@29,@30,@31,@1	; wenn Minus, Neg
 mn2:
 	bst	@0,0

	div_64x64__ @0,@1,@2,@3,@4,@5,@6,@7,@8,@9,@10,@11,@12,@13,@14,@15,@16,@17,@18,@19,@20,@21,@22,@23,@24,@25,@26,@27,@28,@29,@30,@31,@32

	brtc end		; wenn T=1
	neg64 @0,@1,@2,@3,@4,@5,@6,@7,@31	; Ergebnis NEG
	neg64 @8,@9,@10,@11,@12,@13,@14,@15,@31	; Rest NEG
	clt
 end:
.endm

;
;=================================================================================
;=== div unsigned kern ===========================================================
;=== wenn Divisor garantiert !=0 =================================================
;=================================================================================

.macro div_8x8__	; @0 Ergebnis, @1 Rest, @2 Divident, @3 Divisor
		; Division 	8/8 -> 8 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...255
		; Divisor  1...255
		; Ergebnis 0...255
		; Rest     0...254
		; 90/74 Cycles (Divident=255 Divisor=1/Divident=0 Divisor=1),
		; 26 Bytes

	clr @1		; Rest-Register leeren
	clr @0		; Ergebnis leeren
	inc @0		; 1 in Ergebnis
 mn:
	lsl @2		; Divident -> Restregister
	rol @1		; Rest
	cp @1,@3	; mit Divisor vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @1,@3	; Divisor subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0
	brcc mn
.endm

.macro div_16x8__	; @0,1 Ergebnis (@1 MSB), @2 Rest
				; @3,4 Divident (@4 MSB), @5 Divisor
				; @6 Rest-Erweiterung, @7 Null-Register
		; Division 	16/8 -> 16 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...65535
		; Divisor  1...255
		; Ergebnis 0...65535
		; Rest     0...254
		; 261/213 Cycles (Divident=65535 Divisor=1/Divident=0 Divisor=1),
		; 42 Bytes

	clr @2	; Rest-Register leeren
	clr @0	; Ergebnis leeren
	clr @1
	inc @0	; 1 in Ergebnis
	clr @6	; Rest-Erweiterung leeren
	clr @7	; Null-Register leeren
 mn:
	lsl @3	; Divident -> Restregister
	rol @4
	rol @2	; Rest
	rol @6	; Rest-Erweiterung
	cp @2,@5	; Rest mit Divisor vergleichen
	cpc @6,@7	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @2,@5	; Divisor aus Rest subtrahieren
	sbc @6,@7	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	brcc mn
.endm

.macro div_24x8__	; @0,1,2 Ergebnis (@2 MSB), @3 Rest
				; @4,5,6 Divident (@6 MSB), @7 Divisor
				; @8 Rest-Erweiterung, @9 Null-Register
		; Division 	24/8 -> 24 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...16777215
		; Divisor  1...255
		; Ergebnis 0...16777215
		; Rest     0...254
		; 438/366 Cycles (Divident=16777215 Divisor=1/Divident=0 Divisor=1),
		; 48 Bytes

	clr @3	; Rest-Register leeren
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	inc @0	; 1 in Ergebnis
	clr @8	; Rest-Erweiterung leeren
	clr @9	; Null-Register leeren
 mn:
	lsl @4	; Divident -> Restregister
	rol @5
	rol @6
	rol @3	; Rest
	rol @8	; Rest-Erweiterung
	cp @3,@7	; mit Divisor vergleichen
	cpc @8,@9	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @3,@7	; Divisor subtrahieren
	sbc @8,@9	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	brcc mn
.endm 

.macro div_32x8__	; @0,1,2,3 Ergebnis (@3 MSB), @4 Rest
				; @5,6,7,8 Divident (@8 MSB), @9 Divisor
				; @10 Rest-Erweiterung, @11 Null-Register
		; Division 	32/8 -> 32 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...255
		; Ergebnis 0...4294967295
		; Rest     0...254
		; 647/551 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
		; 54 Bytes

	clr @4	; Rest-Register leeren
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	inc @0	; 1 in Ergebnis
	clr @10	; Rest-Erweiterung leeren
	clr @11	; Null-Register leeren
 mn:
	lsl @5	; Divident -> Restregister
	rol @6
	rol @7
	rol @8
	rol @4	; Rest
	rol @10	; Rest-Erweiterung
	cp @4,@9	; mit Divisor vergleichen
	cpc @10,@11	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @4,@9	; Divisor subtrahieren
	sbc @10,@11	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	brcc mn
.endm 

.macro div_40x8__	; @0,1,2,3,4 Ergebnis (@4 MSB), @5 Rest
				; @6,7,8,9,10 Divident (@10 MSB), @11 Divisor
				; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	40/8 -> 40 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...255
		; Ergebnis 0...1099511627775
		; Rest     0...254
		; 888/768 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
		; 60 Bytes

	clr @5	; Rest-Register leeren
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	inc @0; 1 in Ergebnis
	clr @12	; Rest-Erweiterung leeren
	clr @13	; Null-Register leeren
 mn:
	lsl @6	; Divident -> Restregister
	rol @7
	rol @8
	rol @9
	rol @10
	rol @5	; Rest
	rol @12	; Rest-Erweiterung
	cp @5,@11	; mit Divisor vergleichen
	cpc @12,@13	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @5,@11	; Divisor subtrahieren
	sbc @12,@13	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	brcc mn
.endm 

.macro div_48x8__	; @0,1,2,3,4,5 Ergebnis (@5 MSB), @6 Rest
				; @7,8,9,10,11,12 Divident (@12 MSB), @13 Divisor
				; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	48/8 -> 48 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...255
		; Ergebnis 0...281474976710655
		; Rest     0...254
		; 1161/1017 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
		; 66 Bytes

	clr @6	; Rest-Register leeren
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	inc @0; 1 in Ergebnis
	clr @14	; Rest-Erweiterung leeren
	clr @15	; Null-Register leeren
 mn:
	lsl @7	; Divident -> Restregister
	rol @8
	rol @9
	rol @10
	rol @11
	rol @12
	rol @6	; Rest
	rol @14	; Rest-Erweiterung
	cp @6,@13	; mit Divisor vergleichen
	cpc @14,@15	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @6,@13	; Divisor subtrahieren
	sbc @14,@15	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0	; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	brcc mn
.endm 

.macro div_56x8__	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), @7 Rest
				; @8,9,10,11,12,13,14 Divident (@14 MSB), @15 Divisor
				; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	56/8 -> 56 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...255
		; Ergebnis 0...72057594037927935
		; Rest     0...254
		; 1466/1298 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
		; 72 Bytes

	clr @7	; Rest-Register leeren
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	inc @0	; 1 in Ergebnis
	clr @16	; Rest-Erweiterung leeren
	clr @17	; Null-Register leeren
 mn:
	lsl @8	; Divident -> Restregister
	rol @9
	rol @10
	rol @11
	rol @12
	rol @13
	rol @14
	rol @7	; Rest
	rol @16	; Rest-Erweiterung
	cp @7,@15	; mit Divisor vergleichen
	cpc @16,@17	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @7,@15	; Divisor subtrahieren
	sbc @16,@17	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	brcc mn
.endm 

.macro div_64x8__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), @8 Rest
				; @9,10,11,12,13,14,15,16 Divident (@16 MSB), @17 Divisor
				; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	64/8 -> 64 bit, Rest 8 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...255
		; Ergebnis 0...18446744073709551615
		; Rest     0...254
		; 1803/1611 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 78 Bytes

	clr @8	; Rest-Register leeren
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	clr @18	; Rest-Erweiterung leeren
	clr @19	; Null-Register leeren
 mn:
	lsl @9	; Divident -> Restregister
	rol @10
	rol @11
	rol @12
	rol @13
	rol @14
	rol @15
	rol @16
	rol @8	; Rest
	rol @18	; Rest-Erweiterung
	cp @8,@17	; mit Divisor vergleichen
	cpc @18,@19	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@17	; Divisor subtrahieren
	sbc @18,@19	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm 

.macro div_16x16__	; @0,1 Ergebnis (@1 MSB), @2,3 Rest (@3 MSB), 
					; @4,5 Divident (@5 MSB), @6,7 Divisor (@7 MSB)
					; @8 Rest-Erweiterung, @9 Null-Register
		; Division 	16/16 -> 16 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...65535
		; Divisor  1...65535
		; Ergebnis 0...65535
		; Rest     0...65534
		; 310/246 Cycles (Divident=65535 Divisor=1/Divident=0 Divisor=1),
		; 50 Bytes

	clr @2	; Rest-Register leeren
	clr @3
	clr @0	; Ergebnis leeren
	clr @1
	inc @0	; 1 in Ergebnis
	clr @8	; Rest-Erweiterung leeren
	clr @9	; Null-Register leeren
 mn:
	lsl @4		; Divident -> Restregister
	rol @5
	rol @2	; Rest
	rol @3
	rol @8	; Rest-Erweiterung
	cp @2,@6	; mit Divisor vergleichen
	cpc @3,@7
	cpc @8,@9	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @2,@6	; Divisor subtrahieren
	sbc @3,@7
	sbc @8,@9	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	brcc mn
.endm

.macro div_24x16__	; @0,1,2 Ergebnis (@2 MSB), @3,4 Rest (@4 MSB), 
					; @5,6,7 Divident (@7 MSB), @8,9 Divisor (@9 MSB)
					; @10 Rest-Erweiterung, @11 Null-Register
		; Division 	24/16 -> 24 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...16777215
		; Divisor  1...65535
		; Ergebnis 0...16777215
		; Rest     0...65534
		; 511/415 Cycles (Divident=16777215 Divisor=1/Divident=0 Divisor=1),
		; 56 Bytes

	clr @3	; Rest-Register leeren
	clr @4
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	inc @0	; 1 in Ergebnis
	clr @10	; Rest-Erweiterung leeren
	clr @11	; Null-Register leeren
 mn:
	lsl @5		; Divident -> Restregister
	rol @6
	rol @7
	rol @3	; Rest
	rol @4
	rol @10	; Rest-Erweiterung
	cp @3,@8	; mit Divisor vergleichen
	cpc @4,@9
	cpc @10,@11	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @3,@8	; Divisor subtrahieren
	sbc @4,@9
	sbc @10,@11	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	brcc mn
.endm

.macro div_32x16__	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5 Rest (@5 MSB), 
					; @6,7,8,9 Divident (@9 MSB), 
					; @10,11 Divisor (@11 MSB)
					; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	32/16 -> 32 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...65535
		; Ergebnis 0...4294967295
		; Rest     0...65534
		; 744/616 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
		; 62 Bytes

	clr @4	; Rest-Register leeren
	clr @5
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	inc @0	; 1 in Ergebnis
	clr @12	; Rest-Erweiterung leeren
	clr @13	; Null-Register leeren
 mn:
	lsl @6		; Divident -> Restregister
	rol @7
	rol @8
	rol @9
	rol @4	; Rest
	rol @5
	rol @12	; Rest-Erweiterung
	cp @4,@10	; mit Divisor vergleichen
	cpc @5,@11
	cpc @12,@13	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @4,@10	; Divisor subtrahieren
	sbc @5,@11
	sbc @12,@13	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	brcc mn
.endm

.macro div_40x16__	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6 Rest (@6 MSB), 
					; @7,8,9,10,11 Divident (@11 MSB), 
					; @12,13 Divisor (@13 MSB)
					; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	40/16 -> 40 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...65535
		; Ergebnis 0...1099511627775
		; Rest     0...65534
		; 1009/849 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
		; 68 Bytes

	clr @5	; Rest-Register leeren
	clr @6
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	inc @0	; 1 in Ergebnis
	clr @14	; Rest-Erweiterung leeren
	clr @15	; Null-Register leeren
 mn:
	lsl @7		; Divident -> Restregister
	rol @8
	rol @9
	rol @10
	rol @11
	rol @5	; Rest
	rol @6
	rol @14	; Rest-Erweiterung
	cp @5,@12	; mit Divisor vergleichen
	cpc @6,@13
	cpc @14,@15	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @5,@12	; Divisor subtrahieren
	sbc @6,@13
	sbc @14,@15	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	brcc mn
.endm

.macro div_48x16__	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7 Rest (@7 MSB), 
					; @8,9,10,11,12,13 Divident (@13 MSB), 
					; @14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	48/16 -> 48 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...65535
		; Ergebnis 0...281474976710655
		; Rest     0...65534
		; 1306/1114 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
		; 74 Bytes

	clr @6	; Rest-Register leeren
	clr @7
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	inc @0	; 1 in Ergebnis
	clr @16	; Rest-Erweiterung leeren
	clr @17	; Null-Register leeren
 mn:
	lsl @8		; Divident -> Restregister
	rol @9
	rol @10
	rol @11
	rol @12
	rol @13
	rol @6	; Rest
	rol @7
	rol @16	; Rest-Erweiterung
	cp @6,@14	; mit Divisor vergleichen
	cpc @7,@15
	cpc @16,@17	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @6,@14	; Divisor subtrahieren
	sbc @7,@15
	sbc @16,@17	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	brcc mn
.endm

.macro div_56x16__	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8 Rest (@8 MSB), 
					; @9,10,11,12,13,14,15 Divident (@15 MSB), 
					; @16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	56/16 -> 56 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...65535
		; Ergebnis 0...72057594037927935
		; Rest     0...65534
		; 1635/1411 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
		; 80 Bytes

	clr @7	; Rest-Register leeren
	clr @8
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	inc @0	; 1 in Ergebnis
	clr @18	; Rest-Erweiterung leeren
	clr @19	; Null-Register leeren
 mn:
	lsl @9		; Divident -> Restregister
	rol @10
	rol @11
	rol @12
	rol @13
	rol @14
	rol @15
	rol @7	; Rest
	rol @8
	rol @18	; Rest-Erweiterung
	cp @7,@16	; mit Divisor vergleichen
	cpc @8,@17
	cpc @18,@19	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @7,@16	; Divisor subtrahieren
	sbc @8,@17
	sbc @18,@19	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	brcc mn
.endm

.macro div_64x16__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	64/16 -> 64 bit, Rest 16 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...65535
		; Ergebnis 0...18446744073709551615
		; Rest     0...65534
		; 1996/1740 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 86 Bytes

	clr @8	; Rest-Register leeren
	clr @9
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	clr @20	; Rest-Erweiterung leeren
	clr @21	; Null-Register leeren
 mn:
	lsl @10		; Divident -> Restregister
	rol @11
	rol @12
	rol @13
	rol @14
	rol @15
	rol @16
	rol @17
	rol @8	; Rest
	rol @9
	rol @20	; Rest-Erweiterung
	cp @8,@18	; mit Divisor vergleichen
	cpc @9,@19
	cpc @20,@21	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@18	; Divisor subtrahieren
	sbc @9,@19
	sbc @20,@21	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm

.macro div_24x24__	; @0,1,2 Ergebnis (@2 MSB), 
					; @3,4,5 Rest (@5 MSB), 
					; @6,7,8 Divident (@8 MSB), 
					; @9,10,11 Divisor (@11 MSB)
					; @12 Rest-Erweiterung, @13 Null-Register
		; Division 	24/24 -> 24 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...16777215
		; Divisor  1...16777215
		; Ergebnis 0...16777215
		; Rest     0...16777214
		; 584/464 Cycles (Divident=16777215 Divisor=1/Divident=0 Divisor=1),
		; 64 Bytes
	
	clr @3	; Rest-Register leeren
	clr @4
	clr @5
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	inc @0	; 1 in Ergebnis
	clr @12	; Rest-Erweiterung leeren
	clr @13	; Null-Register leeren
 mn:
	lsl @6	; Divident -> Restregister
	rol @7
	rol @8
	rol @3	; Rest
	rol @4
	rol @5
	rol @12	; Rest-Erweiterung
	cp @3,@9	; mit Divisor vergleichen
	cpc @4,@10
	cpc @5,@11
	cpc @12,@13	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @3,@9	; Divisor subtrahieren
	sbc @4,@10
	sbc @5,@11
	sbc @12,@13	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	brcc mn
.endm

.macro div_32x24__	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5,6 Rest (@6 MSB), 
					; @7,8,9,10 Divident (@10 MSB), 
					; @11,12,13 Divisor (@13 MSB)
					; @14 Rest-Erweiterung, @15 Null-Register
		; Division 	32/24 -> 32 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...16777215
		; Ergebnis 0...4294967295
		; Rest     0...16777214
		; 841/681 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
		; 70 Bytes
	
	clr @4	; Rest-Register leeren
	clr @5
	clr @6
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	inc @0	; 1 in Ergebnis
	clr @14	; Rest-Erweiterung leeren
	clr @15	; Null-Register leeren
 mn:
	lsl @7	; Divident -> Restregister
	rol @8
	rol @9
	rol @10
	rol @4	; Rest
	rol @5
	rol @6
	rol @14	; Rest-Erweiterung
	cp @4,@11	; mit Divisor vergleichen
	cpc @5,@12
	cpc @6,@13
	cpc @14,@15	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @4,@11	; Divisor subtrahieren
	sbc @5,@12
	sbc @6,@13
	sbc @14,@15	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	brcc mn
.endm

.macro div_40x24__	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7 Rest (@7 MSB), 
					; @8,9,10,11,12 Divident (@12 MSB), 
					; @13,14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	40/24 -> 40 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...16777215
		; Ergebnis 0...1099511627775
		; Rest     0...16777214
		; 1130/930 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
		; 76 Bytes
	
	clr @5	; Rest-Register leeren
	clr @6
	clr @7
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	inc @0	; 1 in Ergebnis
	clr @16	; Rest-Erweiterung leeren
	clr @17	; Null-Register leeren
 mn:
	lsl @8	; Divident -> Restregister
	rol @9
	rol @10
	rol @11
	rol @12
	rol @5	; Rest
	rol @6
	rol @7
	rol @16	; Rest-Erweiterung
	cp @5,@13	; mit Divisor vergleichen
	cpc @6,@14
	cpc @7,@15
	cpc @16,@17	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @5,@13	; Divisor subtrahieren
	sbc @6,@14
	sbc @7,@15
	sbc @16,@17	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	brcc mn
.endm

.macro div_48x24__	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8 Rest (@8 MSB), 
					; @9,10,11,12,13,14 Divident (@14 MSB), 
					; @15,16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	48/24 -> 48 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...16777215
		; Ergebnis 0...281474976710655
		; Rest     0...16777214
		; 1451/1211 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
		; 82 Bytes
	
	clr @6	; Rest-Register leeren
	clr @7
	clr @8
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	inc @0	; 1 in Ergebnis
	clr @18	; Rest-Erweiterung leeren
	clr @19	; Null-Register leeren
 mn:
	lsl @9	; Divident -> Restregister
	rol @10
	rol @11
	rol @12
	rol @13
	rol @14
	rol @6	; Rest
	rol @7
	rol @8
	rol @18	; Rest-Erweiterung
	cp @6,@15	; mit Divisor vergleichen
	cpc @7,@16
	cpc @8,@17
	cpc @18,@19	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @6,@15	; Divisor subtrahieren
	sbc @7,@16
	sbc @8,@17
	sbc @18,@19	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	brcc mn
.endm

.macro div_56x24__	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15,16 Divident (@16 MSB), 
					; @17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	56/24 -> 56 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...16777215
		; Ergebnis 0...72057594037927935
		; Rest     0...16777214
		; 1804/1524 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
		; 88 Bytes
	
	clr @7	; Rest-Register leeren
	clr @8
	clr @9
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	inc @0	; 1 in Ergebnis
	clr @20	; Rest-Erweiterung leeren
	clr @21	; Null-Register leeren
 mn:
	lsl @10	; Divident -> Restregister
	rol @11
	rol @12
	rol @13
	rol @14
	rol @15
	rol @16
	rol @7	; Rest
	rol @8
	rol @9
	rol @20	; Rest-Erweiterung
	cp @7,@17	; mit Divisor vergleichen
	cpc @8,@18
	cpc @9,@19
	cpc @20,@21	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @7,@17	; Divisor subtrahieren
	sbc @8,@18
	sbc @9,@19
	sbc @20,@21	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	brcc mn
.endm

.macro div_64x24__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10 Rest (@10 MSB), 
					; @11,12,13,14,15,16,17,18 Divident (@18 MSB), 
					; @19,20,21 Divisor (@21 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	64/24 -> 64 bit, Rest 24 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...16777215
		; Ergebnis 0...18446744073709551615
		; Rest     0...16777214
		; 2189/1869 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 94 Bytes
	
	clr @8	; Rest-Register leeren
	clr @9
	clr @10
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	clr @22	; Rest-Erweiterung leeren
	clr @23	; Null-Register leeren
 mn:
	lsl @11	; Divident -> Restregister
	rol @12
	rol @13
	rol @14
	rol @15
	rol @16
	rol @17
	rol @18
	rol @8	; Rest
	rol @9
	rol @10
	rol @22	; Rest-Erweiterung
	cp @8,@19	; mit Divisor vergleichen
	cpc @9,@20
	cpc @10,@21
	cpc @22,@23	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@19	; Divisor subtrahieren
	sbc @9,@20
	sbc @10,@21
	sbc @22,@23	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm

.macro div_32x32__	; @0,1,2,3 Ergebnis (@3 MSB), 
					; @4,5,6,7 Rest (@7 MSB), 
					; @8,9,10,11 Divident (@11 MSB), 
					; @12,13,14,15 Divisor (@15 MSB)
					; @16 Rest-Erweiterung, @17 Null-Register
		; Division 	32/32 -> 32 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...4294967295
		; Divisor  1...4294967295
		; Ergebnis 0...4294967295
		; Rest     0...4294967294
		; 938/746 Cycles (Divident=4294967295 Divisor=1/Divident=0 Divisor=1),
		; 78 Bytes

	clr @4	; Rest-Register leeren
	clr @5
	clr @6
	clr @7
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	inc @0	; 1 in Ergebnis
	clr @16	; Rest-Erweiterung leeren
	clr @17	; Null-Register leeren
 mn:
	lsl @8	; Divident -> Restregister
	rol @9
	rol @10
	rol @11
	rol @4	; Rest
	rol @5
	rol @6
	rol @7
	rol @16	; Rest-Erweiterung
	cp @4,@12	; mit Divisor vergleichen
	cpc @5,@13
	cpc @6,@14
	cpc @7,@15
	cpc @16,@17	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @4,@12	; Divisor subtrahieren
	sbc @5,@13
	sbc @6,@14
	sbc @7,@15
	sbc @16,@17	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	brcc mn
.endm

.macro div_40x32__	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7,8 Rest (@8 MSB), 
					; @9,10,11,12,13 Divident (@13 MSB), 
					; @14,15,16,17 Divisor (@17 MSB)
					; @18 Rest-Erweiterung, @19 Null-Register
		; Division 	40/32 -> 40 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...4294967295
		; Ergebnis 0...1099511627775
		; Rest     0...4294967294
		; 1251/1011 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
		; 84 Bytes

	clr @5	; Rest-Register leeren
	clr @6
	clr @7
	clr @8
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	inc @0	; 1 in Ergebnis
	clr @18	; Rest-Erweiterung leeren
	clr @19	; Null-Register leeren
 mn:
	lsl @9	; Divident -> Restregister
	rol @10
	rol @11
	rol @12
	rol @13
	rol @5	; Rest
	rol @6
	rol @7
	rol @8
	rol @18	; Rest-Erweiterung
	cp @5,@14	; mit Divisor vergleichen
	cpc @6,@15
	cpc @7,@16
	cpc @8,@17
	cpc @18,@19	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @5,@14	; Divisor subtrahieren
	sbc @6,@15
	sbc @7,@16
	sbc @8,@17
	sbc @18,@19	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	brcc mn
.endm

.macro div_48x32__	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14,15 Divident (@15 MSB), 
					; @16,17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	48/32 -> 48 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...4294967295
		; Ergebnis 0...281474976710655
		; Rest     0...4294967294
		; 1596/1308 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
		; 90 Bytes

	clr @6	; Rest-Register leeren
	clr @7
	clr @8
	clr @9
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	inc @0	; 1 in Ergebnis
	clr @20	; Rest-Erweiterung leeren
	clr @21	; Null-Register leeren
 mn:
	lsl @10	; Divident -> Restregister
	rol @11
	rol @12
	rol @13
	rol @14
	rol @15
	rol @6	; Rest
	rol @7
	rol @8
	rol @9
	rol @20	; Rest-Erweiterung
	cp @6,@16	; mit Divisor vergleichen
	cpc @7,@17
	cpc @8,@18
	cpc @9,@19
	cpc @20,@21	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @6,@16	; Divisor subtrahieren
	sbc @7,@17
	sbc @8,@18
	sbc @9,@19
	sbc @20,@21	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	brcc mn
.endm

.macro div_56x32__	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10 Rest (@10 MSB), 
					; @11,12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19,20,21 Divisor (@21 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	56/32 -> 56 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...4294967295
		; Ergebnis 0...72057594037927935
		; Rest     0...4294967294
		; 1973/1637 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
		; 96 Bytes

	clr @7	; Rest-Register leeren
	clr @8
	clr @9
	clr @10
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	inc @0	; 1 in Ergebnis
	clr @22	; Rest-Erweiterung leeren
	clr @23	; Null-Register leeren
 mn:
	lsl @11	; Divident -> Restregister
	rol @12
	rol @13
	rol @14
	rol @15
	rol @16
	rol @17
	rol @7	; Rest
	rol @8
	rol @9
	rol @10
	rol @22	; Rest-Erweiterung
	cp @7,@18	; mit Divisor vergleichen
	cpc @8,@19
	cpc @9,@20
	cpc @10,@21
	cpc @22,@23	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @7,@18	; Divisor subtrahieren
	sbc @8,@19
	sbc @9,@20
	sbc @10,@21
	sbc @22,@23	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	brcc mn
.endm

.macro div_64x32__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17,18,19 Divident (@19 MSB), 
					; @20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	64/32 -> 64 bit, Rest 32 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...4294967295
		; Ergebnis 0...18446744073709551615
		; Rest     0...4294967294
		; 2382/1998 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 102 Bytes

	clr @8	; Rest-Register leeren
	clr @9
	clr @10
	clr @11
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	clr @24	; Rest-Erweiterung leeren
	clr @25	; Null-Register leeren
 mn:
	lsl @12	; Divident -> Restregister
	rol @13
	rol @14
	rol @15
	rol @16
	rol @17
	rol @18
	rol @19
	rol @8	; Rest
	rol @9
	rol @10
	rol @11
	rol @24	; Rest-Erweiterung
	cp @8,@20	; mit Divisor vergleichen
	cpc @9,@21
	cpc @10,@22
	cpc @11,@23
	cpc @24,@25	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@20	; Divisor subtrahieren
	sbc @9,@21
	sbc @10,@22
	sbc @11,@23
	sbc @24,@25	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm

.macro div_40x40__	; @0,1,2,3,4 Ergebnis (@4 MSB), 
					; @5,6,7,8,9 Rest (@9 MSB), 
					; @10,11,12,13,14 Divident (@14 MSB), 
					; @15,16,17,18,19 Divisor (@19 MSB)
					; @20 Rest-Erweiterung, @21 Null-Register
		; Division 	40/40 -> 40 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...1099511627775
		; Divisor  1...1099511627775
		; Ergebnis 0...1099511627775
		; Rest     0...1099511627774
		; 1372/1092 Cycles (Divident=1099511627775 Divisor=1/Divident=0 Divisor=1),
		; 92 Bytes

	clr @5	; Rest-Register leeren
	clr @6
	clr @7
	clr @8
	clr @9
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	inc @0	; 1 in Ergebnis
	clr @20	; Rest-Erweiterung leeren
	clr @21	; Null-Register leeren
 mn:
	lsl @10	; Divident -> Restregister
	rol @11
	rol @12
	rol @13
	rol @14
	rol @5	; Rest
	rol @6
	rol @7
	rol @8
	rol @9
	rol @20	; Rest-Erweiterung
	cp @5,@15	; mit Divisor vergleichen
	cpc @6,@16
	cpc @7,@17
	cpc @8,@18
	cpc @9,@19
	cpc @20,@21	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @5,@15	; Divisor subtrahieren
	sbc @6,@16
	sbc @7,@17
	sbc @8,@18
	sbc @9,@19
	sbc @20,@21	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	brcc mn
.endm

.macro div_48x40__	; @0,1,2,3,4,5 Ergebnis (@0 MSB), 
					; @6,7,8,9,10 Rest (@6 MSB), 
					; @11,12,13,14,15,16 Divident (@11 MSB), 
					; @17,18,19,20,21 Divisor (@17 MSB)
					; @22 Rest-Erweiterung, @23 Null-Register
		; Division 	48/40 -> 48 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...1099511627775
		; Ergebnis 0...281474976710655
		; Rest     0...1099511627774
		; 1741/1405 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
		; 98 Bytes

	clr @6	; Rest-Register leeren
	clr @7
	clr @8
	clr @9
	clr @10
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	inc @0	; 1 in Ergebnis
	clr @22	; Rest-Erweiterung leeren
	clr @23	; Null-Register leeren
 mn:
	lsl @11	; Divident -> Restregister
	rol @12
	rol @13
	rol @14
	rol @15
	rol @16
	rol @6	; Rest
	rol @7
	rol @8
	rol @9
	rol @10
	rol @22	; Rest-Erweiterung
	cp @6,@17	; mit Divisor vergleichen
	cpc @7,@18
	cpc @8,@19
	cpc @9,@20
	cpc @10,@21
	cpc @22,@23	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @6,@17	; Divisor subtrahieren
	sbc @7,@18
	sbc @8,@19
	sbc @9,@20
	sbc @10,@21
	sbc @22,@23	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	brcc mn
.endm

.macro div_56x40__	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17,18 Divident (@18 MSB), 
					; @19,20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	56/40 -> 56 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...1099511627775
		; Ergebnis 0...72057594037927935
		; Rest     0...1099511627774
		; 2142/1750 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
		; 104 Bytes

	clr @7	; Rest-Register leeren
	clr @8
	clr @9
	clr @10
	clr @11
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	inc @0	; 1 in Ergebnis
	clr @24	; Rest-Erweiterung leeren
	clr @25	; Null-Register leeren
 mn:
	lsl @12	; Divident -> Restregister
	rol @13
	rol @14
	rol @15
	rol @16
	rol @17
	rol @18
	rol @7	; Rest
	rol @8
	rol @9
	rol @10
	rol @11
	rol @24	; Rest-Erweiterung
	cp @7,@19	; mit Divisor vergleichen
	cpc @8,@20
	cpc @9,@21
	cpc @10,@22
	cpc @11,@23
	cpc @24,@25	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @7,@19	; Divisor subtrahieren
	sbc @8,@20
	sbc @9,@21
	sbc @10,@22
	sbc @11,@23
	sbc @24,@25	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	brcc mn
.endm

.macro div_64x40__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12 Rest (@12 MSB), 
					; @13,14,15,16,17,18,19,20 Divident (@20 MSB), 
					; @21,22,23,24,25 Divisor (@25 MSB)
					; @26 Rest-Erweiterung, @27 Null-Register
		; Division 	64/40 -> 64 bit, Rest 40 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...1099511627775
		; Ergebnis 0...18446744073709551615
		; Rest     0...1099511627774
		; 2575/2127 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 110 Bytes

	clr @8	; Rest-Register leeren
	clr @9
	clr @10
	clr @11
	clr @12
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	clr @26	; Rest-Erweiterung leeren
	clr @27	; Null-Register leeren
 mn:
	lsl @13	; Divident -> Restregister
	rol @14
	rol @15
	rol @16
	rol @17
	rol @18
	rol @19
	rol @20
	rol @8	; Rest
	rol @9
	rol @10
	rol @11
	rol @12
	rol @26	; Rest-Erweiterung
	cp @8,@21	; mit Divisor vergleichen
	cpc @9,@22
	cpc @10,@23
	cpc @11,@24
	cpc @12,@25
	cpc @26,@27	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@21	; Divisor subtrahieren
	sbc @9,@22
	sbc @10,@23
	sbc @11,@24
	sbc @12,@25
	sbc @26,@27	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm

.macro div_48x48__	; @0,1,2,3,4,5 Ergebnis (@5 MSB), 
					; @6,7,8,9,10,11 Rest (@11 MSB), 
					; @12,13,14,15,16,17 Divident (@17 MSB), 
					; @18,19,20,21,22,23 Divisor (@23 MSB)
					; @24 Rest-Erweiterung, @25 Null-Register
		; Division 	48/48 -> 48 bit, Rest 48 bit (unsigned / unsigned)
		; Divident 0...281474976710655
		; Divisor  1...281474976710655
		; Ergebnis 0...281474976710655
		; Rest     0...281474976710654
		; 1886/1502 Cycles (Divident=281474976710655 Divisor=1/Divident=0 Divisor=1),
		; 106 Bytes

	clr @6	; Rest-Register leeren
	clr @7
	clr @8
	clr @9
	clr @10
	clr @11
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	inc @0	; 1 in Ergebnis
	clr @24	; Rest-Erweiterung leeren
	clr @25	; Null-Register leeren
 mn:
	lsl @12	; Divident -> Restregister
	rol @13
	rol @14
	rol @15
	rol @16
	rol @17
	rol @6	; Rest
	rol @7
	rol @8
	rol @9
	rol @10
	rol @11
	rol @24	; Rest-Erweiterung
	cp @6,@18	; mit Divisor vergleichen
	cpc @7,@19
	cpc @8,@20
	cpc @9,@21
	cpc @10,@22
	cpc @11,@23
	cpc @24,@25	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @6,@18	; Divisor subtrahieren
	sbc @7,@19
	sbc @8,@20
	sbc @9,@21
	sbc @10,@22
	sbc @11,@23
	sbc @24,@25	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	brcc mn
.endm

.macro div_56x48__	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11,12 Rest (@12 MSB), 
					; @13,14,15,16,17,18,19 Divident (@19 MSB), 
					; @20,21,22,23,24,25 Divisor (@25 MSB)
					; @26 Rest-Erweiterung, @27 Null-Register
		; Division 	56/48 -> 56 bit, Rest 48 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...281474976710655
		; Ergebnis 0...72057594037927935
		; Rest     0...281474976710654
		; 2311/1863 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
		; 112 Bytes

	clr @7	; Rest-Register leeren
	clr @8
	clr @9
	clr @10
	clr @11
	clr @12
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	inc @0	; 1 in Ergebnis
	clr @26	; Rest-Erweiterung leeren
	clr @27	; Null-Register leeren
 mn:
	lsl @13	; Divident -> Restregister
	rol @14
	rol @15
	rol @16
	rol @17
	rol @18
	rol @19
	rol @7	; Rest
	rol @8
	rol @9
	rol @10
	rol @11
	rol @12
	rol @26	; Rest-Erweiterung
	cp @7,@20	; mit Divisor vergleichen
	cpc @8,@21
	cpc @9,@22
	cpc @10,@23
	cpc @11,@24
	cpc @12,@25
	cpc @26,@27	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @7,@20	; Divisor subtrahieren
	sbc @8,@21
	sbc @9,@22
	sbc @10,@23
	sbc @11,@24
	sbc @12,@25
	sbc @26,@27	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	brcc mn
.endm

.macro div_64x48__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13 Rest (@13 MSB), 
					; @14,15,16,17,18,19,20,21 Divident (@21 MSB), 
					; @22,23,24,25,26,27 Divisor (@27 MSB)
					; @28 Rest-Erweiterung, @29 Null-Register
		; Division 	64/48 -> 64 bit, Rest 48 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...281474976710655
		; Ergebnis 0...18446744073709551615
		; Rest     0...281474976710654
		; 2768/2256 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 118 Bytes

	clr @8	; Rest-Register leeren
	clr @9
	clr @10
	clr @11
	clr @12
	clr @13
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	clr @28	; Rest-Erweiterung leeren
	clr @29	; Null-Register leeren
 mn:
	lsl @14	; Divident -> Restregister
	rol @15
	rol @16
	rol @17
	rol @18
	rol @19
	rol @20
	rol @21
	rol @8	; Rest
	rol @9
	rol @10
	rol @11
	rol @12
	rol @13
	rol @28	; Rest-Erweiterung
	cp @8,@22	; mit Divisor vergleichen
	cpc @9,@23
	cpc @10,@24
	cpc @11,@25
	cpc @12,@26
	cpc @13,@27
	cpc @28,@29	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@22	; Divisor subtrahieren
	sbc @9,@23
	sbc @10,@24
	sbc @11,@25
	sbc @12,@26
	sbc @13,@27
	sbc @28,@29	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm

.macro div_56x56__	; @0,1,2,3,4,5,6 Ergebnis (@6 MSB), 
					; @7,8,9,10,11,12,13 Rest (@13 MSB), 
					; @14,15,16,17,18,19,20 Divident (@20 MSB), 
					; @21,22,23,24,25,26,27 Divisor (@27 MSB)
					; @28 Rest-Erweiterung, @29 Null-Register
		; Division 	56/56 -> 56 bit, Rest 56 bit (unsigned / unsigned)
		; Divident 0...72057594037927935
		; Divisor  1...72057594037927935
		; Ergebnis 0...72057594037927935
		; Rest     0...72057594037927934
		; 2480/1976 Cycles (Divident=72057594037927935 Divisor=1/Divident=0 Divisor=1),
		; 120 Bytes

	clr @7	; Rest-Register leeren
	clr @8
	clr @9
	clr @10
	clr @11
	clr @12
	clr @13
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	inc @0	; 1 in Ergebnis
	clr @28	; Rest-Erweiterung leeren
	clr @29	; Null-Register leeren
 mn:
	lsl @14	; Divident -> Restregister
	rol @15
	rol @16
	rol @17
	rol @18
	rol @19
	rol @20
	rol @7	; Rest
	rol @8
	rol @9
	rol @10
	rol @11
	rol @12
	rol @13
	rol @28	; Rest-Erweiterung
	cp @7,@21	; mit Divisor vergleichen
	cpc @8,@22
	cpc @9,@23
	cpc @10,@24
	cpc @11,@25
	cpc @12,@26
	cpc @13,@27
	cpc @28,@29	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @7,@21	; Divisor subtrahieren
	sbc @8,@22
	sbc @9,@23
	sbc @10,@24
	sbc @11,@25
	sbc @12,@26
	sbc @13,@27
	sbc @28,@29	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	brcc mn
.endm

.macro div_64x56__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13,14 Rest (@14 MSB), 
					; @15,16,17,18,19,20,21,22 Divident (@22 MSB), 
					; @23,24,25,26,27,28,29 Divisor (@29 MSB)
					; @30 Rest-Erweiterung, @31 Null-Register
		; Division 	64/56 -> 64 bit, Rest 56 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...72057594037927935
		; Ergebnis 0...18446744073709551615
		; Rest     0...72057594037927934
		; 2961/2385 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 126 Bytes

	clr @8	; Rest-Register leeren
	clr @9
	clr @10
	clr @11
	clr @12
	clr @13
	clr @14
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	clr @30	; Rest-Erweiterung leeren
	clr @31	; Null-Register leeren
 mn:
	lsl @15	; Divident -> Restregister
	rol @16
	rol @17
	rol @18
	rol @19
	rol @20
	rol @21
	rol @22
	rol @8	; Rest
	rol @9
	rol @10
	rol @11
	rol @12
	rol @13
	rol @14
	rol @30	; Rest-Erweiterung
	cp @8,@23	; mit Divisor vergleichen
	cpc @9,@24
	cpc @10,@25
	cpc @11,@26
	cpc @12,@27
	cpc @13,@28
	cpc @14,@29
	cpc @30,@31	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@23	; Divisor subtrahieren
	sbc @9,@24
	sbc @10,@25
	sbc @11,@26
	sbc @12,@27
	sbc @13,@28
	sbc @14,@29
	sbc @30,@31	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm

.macro div_64x64__	; @0,1,2,3,4,5,6,7 Ergebnis (@7 MSB), 
					; @8,9,10,11,12,13,14,15 Rest (@15 MSB), 
					; @16,17,18,19,20,21,22,23 Divident (@23 MSB), 
					; @24,25,26,27,28,29,30,31 Divisor (@31 MSB)
					; @29 Divisor-Puffer
					; @30 Rest-Erweiterung
					; @31 Null-Register
					; @32 Ram-Puffer-24 fuer Divisor (3 Bytes in SRAM)
		; Division 	64/64 -> 64 bit, Rest 64 bit (unsigned / unsigned)
		; Divident 0...18446744073709551615
		; Divisor  1...18446744073709551615
		; Ergebnis 0...18446744073709551615
		; Rest     0...18446744073709551614
		; 3928/2904 Cycles (Divident=18446744073709551615 Divisor=1/Divident=0 Divisor=1),
		; 170 Bytes

	clr @8	; Rest-Register leeren
	clr @9
	clr @10
	clr @11
	clr @12
	clr @13
	clr @14
	clr @15
	clr @0	; Ergebnis leeren
	clr @1
	clr @2
	clr @3
	clr @4
	clr @5
	clr @6
	clr @7
	inc @0	; 1 in Ergebnis
	sts @32,@29
	sts @32+1,@30
	sts @32+2,@31
	clr @30	; Rest-Erweiterung leeren
	clr @31	; Null-Register leeren
 mn:
	lsl @16	; Divident -> Restregister
	rol @17
	rol @18
	rol @19
	rol @20
	rol @21
	rol @22
	rol @23
	rol @8	; Rest
	rol @9
	rol @10
	rol @11
	rol @12
	rol @13
	rol @14
	rol @15
	rol @30	; Rest-Erweiterung
	cp @8,@24	; mit Divisor vergleichen
	cpc @9,@25
	cpc @10,@26
	cpc @11,@27
	cpc @12,@28
	lds @29,@32
	cpc @13,@29
	lds @29,@32+1
	cpc @14,@29
	lds @29,@32+2
	cpc @15,@29
	cpc @30,@31	; Rest-Erweiterung mit Null-Register vergleichen
	brcs  mm	; Wenn kleiner, Subtraktion ueberspringen
	sub @8,@24	; Divisor subtrahieren
	sbc @9,@25
	sbc @10,@26
	sbc @11,@27
	sbc @12,@28
	lds @29,@32
	sbc @13,@29
	lds @29,@32+1
	sbc @14,@29
	lds @29,@32+2
	sbc @15,@29
	sbc @30,@31	; Null-Register aus Rest-Erweiterung subtrahieren
	sec			; C=1
	rjmp PC+2
 mm:
	clc			; C=0
	rol @0		; Ergebnis rollen
	rol @1
	rol @2
	rol @3
	rol @4
	rol @5
	rol @6
	rol @7
	brcc mn
.endm

;=================================================================================
;=== NEG-Macro ===================================================================
;=================================================================================
;
#ifndef _NEGXX_
#define _NEGXX_

.macro neg16	; @0,1 Data (@1 MSB), @2 temp, 5c,10b
	clr @2
	com @0
	com @1
	adc @0,@2
	adc @1,@2
.endm

.macro neg24	; @0-2 Data (@2 MSB), @3 temp, 7c,14b
	clr @3
	com @0
	com @1
	com @2
	adc @0,@3
	adc @1,@3
	adc @2,@3
.endm

.macro neg32	; @0-3 Data (@3 MSB), @4 temp, 9c,18b
	clr @4
	com @0
	com @1
	com @2
	com @3
	adc @0,@4
	adc @1,@4
	adc @2,@4
	adc @3,@4
.endm

.macro neg40	; @0-4 Data (@4 MSB), @5 temp, 11c,22b
	clr @5
	com @0
	com @1
	com @2
	com @3
	com @4
	adc @0,@5
	adc @1,@5
	adc @2,@5
	adc @3,@5
	adc @4,@5
.endm

.macro neg48	; @0-5 Data (@5 MSB), @6 temp, 13c,26b
	clr @6
	com @0
	com @1
	com @2
	com @3
	com @4
	com @5
	adc @0,@6
	adc @1,@6
	adc @2,@6
	adc @3,@6
	adc @4,@6
	adc @5,@6
.endm

.macro neg56	; @0-6 Data (@6 MSB), @7 temp, 15c,30b
	clr @7
	com @0
	com @1
	com @2
	com @3
	com @4
	com @5
	com @6
	adc @0,@7
	adc @1,@7
	adc @2,@7
	adc @3,@7
	adc @4,@7
	adc @5,@7
	adc @6,@7
.endm

.macro neg64	; @0-7 Data (@7 MSB), @8 temp, 17c,34b
	clr @8
	com @0
	com @1
	com @2
	com @3
	com @4
	com @5
	com @6
	com @7
	adc @0,@8
	adc @1,@8
	adc @2,@8
	adc @3,@8
	adc @4,@8
	adc @5,@8
	adc @6,@8
	adc @7,@8
.endm

#endif /* _NEGXX_ */
;=================================================================================
;=================================================================================
;=================================================================================

 #endif /* _DIVISION_ */
